#ifndef SINGLETOPDPDMAKER_CONTAINERTHINNING_H
#define SINGLETOPDPDMAKER_CONTAINERTHINNING_H

#include <string>
#include <vector>

#include "GaudiKernel/Algorithm.h"
#include "GaudiKernel/MsgStream.h"
#include "GaudiKernel/ServiceHandle.h"
#include "AthenaKernel/IThinningSvc.h"
#include "StoreGate/StoreGate.h"

#include "egammaEvent/PhotonContainer.h"
#include "egammaEvent/ElectronContainer.h"
#include "muonEvent/MuonContainer.h"
#include "tauEvent/TauJetContainer.h"
#include "JetEvent/JetCollection.h"
#include "CompositeParticleEvent/CompositeParticleContainer.h"
#include "McParticleEvent/TruthParticleContainer.h"

#include "SingleTopDPDMaker/SelectionInfoContainer.h"
#include "SingleTopDPDMaker/SelectionInfo.h"

class ContainerThinning : public Algorithm
{

public:

  ContainerThinning(const std::string& name, ISvcLocator* pSvcLocator);
  virtual ~ContainerThinning();
  
  StatusCode initialize();
  StatusCode finalize();
  StatusCode execute();
    
  bool TestContainerType();
    
  template <class CT> bool Thin(unsigned int, const CT*);
      
private:

  StoreGateSvc * aStoreGateSvc;
  
  int InputEventNumber;
  int OutputEventNumber;
  
  std::vector<std::string> ContainerName;
  std::vector<std::string> ContainerType;
  
  std::vector<std::string> SelectionInfoContainerName;
  
  std::vector<std::vector<std::string> > RequiredSelectionLabel;
      
  const PhotonContainer            * aPhotonContainer;
  const ElectronContainer          * aElectronContainer;
  const Analysis::MuonContainer    * aMuonContainer;
  const Analysis::TauJetContainer  * aTauJetContainer;
  const JetCollection              * aJetContainer;
  const CompositeParticleContainer * aCompositeParticleContainer;
  const TruthParticleContainer     * aTruthParticleContainer;
      
  SelectionInfoContainer * aSelectionInfoContainer;
  
  ServiceHandle<IThinningSvc> aThinningSvc;
                                   
};

#endif







