#ifndef SINGLETOPDPDMAKER_EFDECISIONSELECTION_H
#define SINGLETOPDPDMAKER_EFDECISIONSELECTION_H

#include <string>
#include <vector>
#include <set>

#include "GaudiKernel/Algorithm.h"
#include "GaudiKernel/MsgStream.h"
#include "GaudiKernel/ToolHandle.h"
#include "StoreGate/StoreGate.h"

#include "TrigDecision/TrigDecisionTool.h"

#include "TrigMuonEvent/TrigMuonEF.h"
#include "TrigMuonEvent/TrigMuonEFContainer.h"
#include "TrigParticle/TrigEFBjet.h"
#include "TrigParticle/TrigEFBjetContainer.h"
#include "egammaEvent/egamma.h"
#include "egammaEvent/egammaContainer.h"
#include "tauEvent/TauJet.h"
#include "tauEvent/TauJetContainer.h"
#include "JetEvent/Jet.h"
#include "JetEvent/JetCollection.h"

#include "NavFourMom/INavigable4MomentumCollection.h"

class EFDecisionSelection : public Algorithm
{

public:

  EFDecisionSelection(const std::string& name, ISvcLocator* pSvcLocator);
  virtual ~EFDecisionSelection();
  
  StatusCode initialize();
  StatusCode finalize();
  StatusCode execute();
      
  StatusCode executeElectron();
  StatusCode executePhoton();
  StatusCode executeMuon();
  StatusCode executeTau();
  StatusCode executeJet();
  StatusCode executeBJet();
    
  void SelectElectrons();
  void SelectPhotons();
  void SelectMuons();
  void SelectTaus();
  void SelectJets();
  void SelectBJets();
  
  bool TestContainerType();
  bool TestChainSize();
          
private:

  StoreGateSvc * aStoreGateSvc;
  
  int InputEventNumber;
  int OutputEventNumber;
  
  std::vector<std::string> ElectronChainName;
  std::vector<std::string> PhotonChainName;
  std::vector<std::string> MuonChainName;
  std::vector<std::string> TauChainName;
  std::vector<std::string> JetChainName;
  std::vector<std::string> BJetChainName;
  
  bool GetElectronPassedFeatures;
  bool GetPhotonPassedFeatures;
  bool GetMuonPassedFeatures;
  bool GetTauPassedFeatures;
  bool GetJetPassedFeatures;
  bool GetBJetPassedFeatures;
  
  std::vector<std::string> OutputContainerName;
  
  ToolHandle<TrigDec::TrigDecisionTool> aTriggerDecisionTool;
    
  std::string ElectronContainerName;
  std::string PhotonContainerName;
  std::string MuonContainerName;
  std::string TauContainerName;
  std::string JetContainerName;
  std::string BJetContainerName;
  
  bool isElectron;
  bool isPhoton;
  bool isMuon;
  bool isTau;
  bool isJet;
  bool isBJet;
  
  std::set<const egammaContainer*>           ElectronContainers;
  std::set<const egammaContainer*>           PhotonContainers;
  std::set<const TrigMuonEFContainer*>       MuonContainers;
  std::set<const Analysis::TauJetContainer*> TauContainers;
  std::set<const JetCollection*>             JetContainers;
  std::set<const TrigEFBjetContainer*>       BJetContainers;
        
  INavigable4MomentumCollection * aElectronContainer;
  INavigable4MomentumCollection * aPhotonContainer;
  INavigable4MomentumCollection * aMuonContainer;
  INavigable4MomentumCollection * aTauContainer;
  INavigable4MomentumCollection * aJetContainer;
  INavigable4MomentumCollection * aBJetContainer;
                            
};

#endif







