#ifndef SINGLETOPDPDMAKER_EFTRIGGERSELECTION_H
#define SINGLETOPDPDMAKER_EFTRIGGERSELECTION_H

#include <string>
#include <vector>

#include "GaudiKernel/Algorithm.h"
#include "GaudiKernel/MsgStream.h"
#include "StoreGate/StoreGate.h"
#include "StoreGate/DataHandle.h"

#include "TrigMuonEvent/TrigMuonEF.h"
#include "TrigMuonEvent/TrigMuonEFContainer.h"
#include "TrigParticle/TrigEFBjet.h"
#include "TrigParticle/TrigEFBjetContainer.h"
#include "egammaEvent/egamma.h"
#include "egammaEvent/egammaContainer.h"
#include "tauEvent/TauJet.h"
#include "tauEvent/TauJetContainer.h"
#include "JetEvent/Jet.h"
#include "JetEvent/JetCollection.h"

#include "NavFourMom/INavigable4MomentumCollection.h"

class EFTriggerSelection : public Algorithm
{

public:

  EFTriggerSelection(const std::string& name, ISvcLocator* pSvcLocator);
  virtual ~EFTriggerSelection();
  
  StatusCode initialize();
  StatusCode finalize();
  StatusCode execute();
      
  StatusCode executeEgamma();
  StatusCode executeMuon();
  StatusCode executeTau();
  StatusCode executeJet();
  StatusCode executeBJet();
    
  void SelectEgammas();
  void SelectMuons();
  void SelectTaus();
  void SelectJets();
  void SelectBJets();
  
  bool TestContainerType();
  
  template <class CT, class T> bool Select(const CT*, T*, std::string);
          
private:

  StoreGateSvc * aStoreGateSvc;
  
  int InputEventNumber;
  int OutputEventNumber;
  
  std::vector<std::string> OutputContainerName;
    
  std::string EgammaContainerName;
  std::string MuonContainerName;
  std::string TauContainerName;
  std::string JetContainerName;
  std::string BJetContainerName;
  
  bool isEgamma;
  bool isMuon;
  bool isTau;
  bool isJet;
  bool isBJet;
    
  const DataHandle<egammaContainer>           EgammaItrB;
  const DataHandle<egammaContainer>           EgammaItrE;
  const DataHandle<TrigMuonEFContainer>       MuonItrB;
  const DataHandle<TrigMuonEFContainer>       MuonItrE;
  const DataHandle<Analysis::TauJetContainer> TauItrB;
  const DataHandle<Analysis::TauJetContainer> TauItrE;
  const DataHandle<JetCollection>             JetItrB;
  const DataHandle<JetCollection>             JetItrE;
  const DataHandle<TrigEFBjetContainer>       BJetItrB;
  const DataHandle<TrigEFBjetContainer>       BJetItrE;
    
  INavigable4MomentumCollection * aEgammaContainer;
  INavigable4MomentumCollection * aMuonContainer;
  INavigable4MomentumCollection * aTauContainer;
  INavigable4MomentumCollection * aJetContainer;
  INavigable4MomentumCollection * aBJetContainer;
                            
};

#endif







