#ifndef SINGLETOPDPDMAKER_ELECTRONSELECTION_H
#define SINGLETOPDPDMAKER_ELECTRONSELECTION_H

#include <string>

#include "GaudiKernel/Algorithm.h"
#include "GaudiKernel/MsgStream.h"
#include "StoreGate/StoreGate.h"

#include "egammaEvent/ElectronContainer.h"
#include "egammaEvent/Electron.h"
#include "egammaEvent/EMShower.h"
#include "egammaEvent/egammaParamDefs.h"
#include "egammaEvent/egammaPIDdefs.h"
#include "JetEvent/JetCollection.h"
#include "JetEvent/Jet.h"

#include "FourMom/P4Help.h"

#include "SingleTopDPDMaker/SelectionInfoContainer.h"
#include "SingleTopDPDMaker/SelectionInfo.h"

class ElectronSelection : public Algorithm
{

public:

  ElectronSelection(const std::string& name, ISvcLocator* pSvcLocator);
    
  virtual ~ElectronSelection();
  
  StatusCode initialize();
  StatusCode finalize();
  StatusCode execute();
  
  void Select();
    
  bool TestAuthorOption();
  bool TestEmMaskOption();
  bool TestConeSizeOption();
  
  bool SelectElectron(const Analysis::Electron*);
  
  bool TestAuthor    (const Analysis::Electron*);
  bool TestEmMask    (const Analysis::Electron*);
  bool TestEtCone    (const Analysis::Electron*);
  bool TestJetDeltaR (const Analysis::Electron*);
  
private:

  StoreGateSvc * aStoreGateSvc;
  
  int InputEventNumber;
  int OutputEventNumber;
  
  int InputObjectNumber;
  int OutputObjectNumber;
  
  std::string InputContainerName;
  std::string OutputContainerName;
  std::string JetContainerName;
  
  std::string SelectionInfoContainerName;
  std::string SelectionLabel;
  
  const ElectronContainer * aInputContainer;
  ElectronContainer       * aOutputContainer;
  const JetCollection     * aJetContainer;
  
  bool ApplyEtConeCut;
  bool ApplyJetDRCut;
  bool ApplyEtaCrackCut;
  
  std::string EmMask;
  std::string Author;
  
  double PtCut;
  double EtaCut;
  double ConeSize;
  double EtConeCut;
  double JetDRCut;
  double MinEtaCrack;
  double MaxEtaCrack;
  
  egammaParameters::ParamDef ConeSizeParameter;
  
  std::vector<bool> Mask;
  
  SelectionInfoContainer * aSelectionInfoContainer;
  
};

#endif
