#ifndef SINGLETOPDPDMAKER_EVENTFILTER_H
#define SINGLETOPDPDMAKER_EVENTFILTER_H

#include <string>

#include "GaudiKernel/Algorithm.h"
#include "GaudiKernel/MsgStream.h"
#include "StoreGate/StoreGate.h"

#include "MissingETEvent/MissingET.h"
#include "egammaEvent/PhotonContainer.h"
#include "egammaEvent/ElectronContainer.h"
#include "muonEvent/MuonContainer.h"
#include "tauEvent/TauJetContainer.h"
#include "JetEvent/JetCollection.h"

class EventFilter : public Algorithm
{

public:

  EventFilter(const std::string& name, ISvcLocator* pSvcLocator);
  virtual ~EventFilter();
  
  StatusCode initialize();
  StatusCode finalize();
  StatusCode execute();
  
  bool TestContainerType();
  
  template <class CT> int ContainerSize(const CT*, std::string, double, double);
        
private:

  StoreGateSvc * aStoreGateSvc;
  
  int InputEventNumber;
  int OutputEventNumber;    

  std::string MissingEtName;
  
  std::vector<std::string> ContainerName;
  std::vector<std::string> ContainerType;
  
  std::vector<std::string> FirstContainerName;
  std::vector<std::string> SecondContainerName;
  std::vector<std::string> FirstContainerType;
  std::vector<std::string> SecondContainerType;
  
  const MissingET                 * aMissingEt;
  
  const PhotonContainer           * aPhotonContainer;
  const ElectronContainer         * aElectronContainer;
  const Analysis::MuonContainer   * aMuonContainer;
  const Analysis::TauJetContainer * aTauJetContainer;
  const JetCollection             * aJetContainer;
    
  double MissingEtThreshold;
  
  std::vector<double> PtThreshold;
  std::vector<double> FirstPtThreshold;
  std::vector<double> SecondPtThreshold;
  
  std::vector<double> EtaThreshold;
  std::vector<double> FirstEtaThreshold;
  std::vector<double> SecondEtaThreshold;
  
  std::vector<int> MinNumber;
  std::vector<int> MaxNumber;
  
  std::vector<int> MinSumNumber;
  std::vector<int> MaxSumNumber;
                      
};

#endif







