#ifndef SINGLETOPDPDMAKER_L1TRIGGERSELECTION_H
#define SINGLETOPDPDMAKER_L1TRIGGERSELECTION_H

#include <string>

#include "GaudiKernel/Algorithm.h"
#include "GaudiKernel/MsgStream.h"
#include "StoreGate/StoreGate.h"

#include "NavFourMom/INavigable4MomentumCollection.h"

#include "AnalysisTriggerEvent/LVL1_ROI.h"
#include "AnalysisTriggerEvent/Muon_ROI.h"
#include "AnalysisTriggerEvent/EmTau_ROI.h"
#include "AnalysisTriggerEvent/Jet_ROI.h"

class L1TriggerSelection : public Algorithm
{

public:

  L1TriggerSelection(const std::string& name, ISvcLocator* pSvcLocator);
  virtual ~L1TriggerSelection();
  
  StatusCode initialize();
  StatusCode finalize();
  StatusCode execute();
      
  StatusCode executeMuon();
  StatusCode executeEmTau();
  StatusCode executeJet();
  
  void SelectMuons();
  void SelectEmTaus();
  void SelectJets();
  
  bool TestContainerType();
          
private:

  StoreGateSvc * aStoreGateSvc;
  
  int InputEventNumber;
  int OutputEventNumber;
  
  std::string Level1Name;
  
  std::vector<std::string> OutputContainerName;
    
  std::string MuonContainerName;
  std::string EmTauContainerName;
  std::string JetContainerName;
  
  bool isMuon;
  bool isEmTau;
  bool isJet;
    
  const LVL1_ROI * aLevel1;
      
  INavigable4MomentumCollection * aMuonContainer;
  INavigable4MomentumCollection * aEmTauContainer;
  INavigable4MomentumCollection * aJetContainer;
                            
};

#endif







