#ifndef SINGLETOPDPDMAKER_L2TRIGGERSELECTION_H
#define SINGLETOPDPDMAKER_L2TRIGGERSELECTION_H

#include <string>
#include <vector>
#include <algorithm>

#include "GaudiKernel/Algorithm.h"
#include "GaudiKernel/MsgStream.h"
#include "StoreGate/StoreGate.h"
#include "StoreGate/DataHandle.h"

#include "TrigParticle/TrigElectron.h"
#include "TrigParticle/TrigElectronContainer.h"
#include "TrigParticle/TrigPhoton.h"
#include "TrigParticle/TrigPhotonContainer.h"
#include "TrigParticle/TrigL2Bjet.h"
#include "TrigParticle/TrigL2BjetContainer.h"
#include "TrigParticle/TrigTau.h"
#include "TrigMuonEvent/CombinedMuonFeature.h"
#include "TrigCaloEvent/TrigT2Jet.h"

#include "NavFourMom/INavigable4MomentumCollection.h"

class L2TriggerSelection : public Algorithm
{

public:

  L2TriggerSelection(const std::string& name, ISvcLocator* pSvcLocator);
  virtual ~L2TriggerSelection();
  
  StatusCode initialize();
  StatusCode finalize();
  StatusCode execute();
      
  StatusCode executeElectron();
  StatusCode executePhoton();
  StatusCode executeMuon();
  StatusCode executeTau();
  StatusCode executeJet();
  StatusCode executeBJet();
    
  void SelectElectrons();
  void SelectPhotons();
  void SelectMuons();
  void SelectTaus();
  void SelectJets();
  void SelectBJets();
  
  bool TestContainerType();
          
private:

  StoreGateSvc * aStoreGateSvc;
  
  int InputEventNumber;
  int OutputEventNumber;
  
  std::vector<std::string> OutputContainerName;
    
  std::string ElectronContainerName;
  std::string PhotonContainerName;
  std::string MuonContainerName;
  std::string TauContainerName;
  std::string JetContainerName;
  std::string BJetContainerName;
  
  bool isElectron;
  bool isPhoton;
  bool isMuon;
  bool isTau;
  bool isJet;
  bool isBJet;
    
  const DataHandle<TrigElectronContainer> ElectronItrB;
  const DataHandle<TrigElectronContainer> ElectronItrE;
  const DataHandle<TrigPhotonContainer>   PhotonItrB;
  const DataHandle<TrigPhotonContainer>   PhotonItrE;
  const DataHandle<CombinedMuonFeature>   MuonItrB;
  const DataHandle<CombinedMuonFeature>   MuonItrE;
  const DataHandle<TrigTau>               TauItrB;
  const DataHandle<TrigTau>               TauItrE;
  const DataHandle<TrigT2Jet>             JetItrB;
  const DataHandle<TrigT2Jet>             JetItrE;
  const DataHandle<TrigL2BjetContainer>   BJetItrB;
  const DataHandle<TrigL2BjetContainer>   BJetItrE;
    
  INavigable4MomentumCollection * aElectronContainer;
  INavigable4MomentumCollection * aPhotonContainer;
  INavigable4MomentumCollection * aMuonContainer;
  INavigable4MomentumCollection * aTauContainer;
  INavigable4MomentumCollection * aJetContainer;
  INavigable4MomentumCollection * aBJetContainer;
                            
};

#endif







