#ifndef SINGLETOPDPDMAKER_MUONSELECTION_H
#define SINGLETOPDPDMAKER_MUONSELECTION_H

#include <string>

#include "GaudiKernel/Algorithm.h"
#include "GaudiKernel/MsgStream.h"
#include "StoreGate/StoreGate.h"

#include "muonEvent/MuonContainer.h"
#include "muonEvent/Muon.h"
#include "muonEvent/MuonParamDefs.h"
#include "JetEvent/JetCollection.h"
#include "JetEvent/Jet.h"

#include "FourMom/P4Help.h"

#include "SingleTopDPDMaker/SelectionInfoContainer.h"
#include "SingleTopDPDMaker/SelectionInfo.h"

class MuonSelection : public Algorithm
{

public:

  MuonSelection(const std::string& name, ISvcLocator* pSvcLocator);
    
  virtual ~MuonSelection();
  
  StatusCode initialize();
  StatusCode finalize();
  StatusCode execute();
  
  void Select();
  
  bool TestAuthorOption();
  bool TestConeSizeOption();
  
  bool SelectMuon   (const Analysis::Muon*);
  
  bool TestAuthor   (const Analysis::Muon*);
  bool TestJetDeltaR(const Analysis::Muon*);
  
private:

  StoreGateSvc * aStoreGateSvc;
  
  int InputEventNumber;
  int OutputEventNumber;
  
  int InputObjectNumber;
  int OutputObjectNumber;
  
  std::string InputContainerName;
  std::string OutputContainerName;
  std::string JetContainerName;
  
  std::string SelectionInfoContainerName;
  std::string SelectionLabel;
  
  const Analysis::MuonContainer * aInputContainer;
  Analysis::MuonContainer       * aOutputContainer;
  const JetCollection           * aJetContainer;
  
  bool ApplyIsHighPtCut;
  bool ApplyBestMatchCut;
  bool ApplyEtConeCut;
  bool ApplyJetDRCut;
  
  std::string EmMask;
  std::string Author;
  
  double PtCut;
  double EtaCut;
  double ConeSize;
  double EtConeCut;
  double JetDRCut;
  
  MuonParameters::ParamDef ConeSizeParameter;
  
  std::vector<bool> Mask;
  
  SelectionInfoContainer * aSelectionInfoContainer;

};

#endif
