#ifndef SINGLETOPDPDMAKER_NTUPLEMAKER_H
#define SINGLETOPDPDMAKER_NTUPLEMAKER_H

#include <string>

#include "GaudiKernel/Algorithm.h"
#include "GaudiKernel/MsgStream.h"
#include "StoreGate/StoreGate.h"

#include "EventInfo/EventInfo.h"
#include "EventInfo/EventID.h"
#include "MissingETEvent/MissingET.h"
#include "egammaEvent/ElectronContainer.h"
#include "muonEvent/MuonContainer.h"
#include "JetEvent/JetCollection.h"
#include "ParticleEvent/NeutrinoContainer.h"
#include "ParticleEvent/Neutrino.h"

#include "EventKernel/IParticle.h"
#include "NavFourMom/IParticleContainer.h"
#include "FourMom/P4Help.h"

#include "AnalysisUtils/AnalysisMisc.h"
#include "SpecialUtils/NeutrinoUtils.h"

#include "CLHEP/Vector/LorentzVector.h"
#include "CLHEP/Vector/ThreeVector.h"

#include "TFile.h"
#include "TNtupleD.h"

class NtupleMaker : public Algorithm
{

public:

  NtupleMaker(const std::string& name, ISvcLocator* pSvcLocator);
  virtual ~NtupleMaker();
  
  StatusCode initialize();
  StatusCode finalize();
  StatusCode execute();
  
  void SortContainers();
  
  void CreateNtuple();
  void ClearNtuple();
  void FillNtuple();
  void WriteNtuple();
  
  void ClearLeptons();
  void ClearJets();
  void ClearLeptonsJets();
  void ClearWLeptonic();
  void ClearWHadronic();
  void ClearTopLeptonic();
  void ClearTopHadronic();
  void ClearGlobal();
  void ClearTopological();
  void ClearWLeptonicPolarization();
  void ClearWHadronicPolarization();
  void ClearTopPolarization();
  
  void FillInfo();
  void FillLeptons();
  void FillJets();
  void FillLeptonsJets();
  void FillWLeptonic();
  void FillWHadronic();
  void FillTopLeptonic();
  void FillTopHadronic();
  void FillGlobal();
  void FillTopological();
  void FillWLeptonicPolarization();
  void FillWHadronicPolarization();
  void FillTopPolarization();
  
  double RelativeCosine(HepLorentzVector&, HepLorentzVector&);
        
private:

  StoreGateSvc * aStoreGateSvc;
  TFile        * aFile;
  TNtupleD     * aNtuple;
  
  int NbInputEvents;
  int NbOutputEvents;
  
  std::string FileName;
  std::string NtupleName;
  
  std::string EventInfoName;
  std::string MissingEtName;
  std::string ElectronContainerName;
  std::string MuonContainerName;
  std::string TaggedJetContainerName;
  std::string UntaggedJetContainerName;
  
  const EventInfo               * aEventInfo;
  const MissingET               * aMissingEt;
  const ElectronContainer       * aElectronContainer;
  const Analysis::MuonContainer * aMuonContainer;
  const JetCollection           * aTaggedJetContainer;
  const JetCollection           * aUntaggedJetContainer;
  
  IParticleContainer * aSortedLeptonContainer;
  IParticleContainer * aSortedJetContainer;
  IParticleContainer * aSortedTaggedJetContainer;
  IParticleContainer * aSortedUntaggedJetContainer;
  
  IParticle * aLepton;
  IParticle * aBJet1;
  IParticle * aBJet2;
  IParticle * aUJet1;
  IParticle * aUJet2;
  IParticle * aUJet3;
  
  NeutrinoContainer * aNeutrinoContainer;
  Neutrino          * aNeutrino;
      
  HepLorentzVector hlvLepton;
  HepLorentzVector hlvNeutrino;
  HepLorentzVector hlvUJet1;
  HepLorentzVector hlvUJet2;
  HepLorentzVector hlvUJet3;
  HepLorentzVector hlvBJet1;
  HepLorentzVector hlvBJet2;
  
  HepLorentzVector hlvWlep;
  HepLorentzVector hlvWhad12;
  HepLorentzVector hlvWhad13;
  HepLorentzVector hlvWhad23;
  
  HepLorentzVector hlvTlepBJ1;
  HepLorentzVector hlvTlepBJ2;
  HepLorentzVector hlvThad12BJ1;
  HepLorentzVector hlvThad12BJ2;
  HepLorentzVector hlvThad13BJ1;
  HepLorentzVector hlvThad13BJ2;
  HepLorentzVector hlvThad23BJ1;
  HepLorentzVector hlvThad23BJ2;
    
  HepLorentzVector hlvLeptonRWlep;
  HepLorentzVector hlvNeutrinoRWlep;
  HepLorentzVector hlvUJet1RWhad12;
  HepLorentzVector hlvUJet2RWhad12;
  HepLorentzVector hlvUJet1RWhad13;
  HepLorentzVector hlvUJet3RWhad13;
  HepLorentzVector hlvUJet2RWhad23;
  HepLorentzVector hlvUJet3RWhad23;
  
  HepLorentzVector hlvLeptonRTlepBJ1;
  HepLorentzVector hlvNeutrinoRTlepBJ1;
  HepLorentzVector hlvBJet1RTlepBJ1;
  HepLorentzVector hlvWlepRTlepBJ1;
  
  HepLorentzVector hlvLeptonRTlepBJ2;
  HepLorentzVector hlvNeutrinoRTlepBJ2;
  HepLorentzVector hlvBJet2RTlepBJ2;
  HepLorentzVector hlvWlepRTlepBJ2;
  
  HepLorentzVector hlvUJet1RThad12BJ1;
  HepLorentzVector hlvUJet2RThad12BJ1;
  HepLorentzVector hlvBJet1RThad12BJ1;
  HepLorentzVector hlvWhad12RThad12BJ1;
  HepLorentzVector hlvUJet1RThad12BJ2;
  HepLorentzVector hlvUJet2RThad12BJ2;
  HepLorentzVector hlvBJet2RThad12BJ2;
  HepLorentzVector hlvWhad12RThad12BJ2;
  
  HepLorentzVector hlvUJet1RThad13BJ1;
  HepLorentzVector hlvUJet3RThad13BJ1;
  HepLorentzVector hlvBJet1RThad13BJ1;
  HepLorentzVector hlvWhad13RThad13BJ1;
  HepLorentzVector hlvUJet1RThad13BJ2;
  HepLorentzVector hlvUJet3RThad13BJ2;
  HepLorentzVector hlvBJet2RThad13BJ2;
  HepLorentzVector hlvWhad13RThad13BJ2;
  
  HepLorentzVector hlvUJet2RThad23BJ1;
  HepLorentzVector hlvUJet3RThad23BJ1;
  HepLorentzVector hlvBJet1RThad23BJ1;
  HepLorentzVector hlvWhad23RThad23BJ1;
  HepLorentzVector hlvUJet2RThad23BJ2;
  HepLorentzVector hlvUJet3RThad23BJ2;
  HepLorentzVector hlvBJet2RThad23BJ2;
  HepLorentzVector hlvWhad23RThad23BJ2;
  
  double RunNumber;
  double EventNumber;
  
  double NbSelLep;
  double LeptonType;
  double LeptonPt;
  double LeptonEta;
  double LeptonPhi;
  double LeptonCharge;
  double Met;
  double MetPhi;
  double NuPz;
  double MetLep;
  double cosDPhi_LepMet;
  double DEta_LepMet;
  double DR_LepMet;
  double MtWlep;
  double MetLepTCut;
  
  double NbSelJet;
  double Jphi[4];
  double Jeta[4];
  double Jpt[4];
  double NbSelBJet;
  double BJ1phi;
  double BJ1eta;
  double BJ1pt;
  double BJ2phi;
  double BJ2eta;
  double BJ2pt;
  double Mass_BJ1BJ2;
  double NbSelUJet;
  double UJ1phi;
  double UJ1eta;
  double UJ1pt;
  double UJ2phi;
  double UJ2eta;
  double UJ2pt;
  double UJ3phi;
  double UJ3eta;
  double UJ3pt;
  double cosDPhi_BJ1BJ2;
  double cosDPhi_UJ1UJ2;
  double cosDPhi_BJ1UJ1;
  double cosDPhi_BJ2UJ1;
  double cosDPhi_BJ1UJ2;
  double cosDPhi_BJ2UJ2;
  double cosDPhi_BJ1UJ3;
  double DR_BJ1BJ2;
  double DR_UJ1UJ2;
  double DR_BJ1UJ1;
  double DR_BJ2UJ1;
  double DR_BJ1UJ2;
  double DR_BJ2UJ2;
  double DR_BJ1UJ3;
  double DEta_BJ1BJ2;
  double DEta_UJ1UJ2;
  double DEta_BJ1UJ1;
  double DEta_BJ2UJ1;
  double DEta_BJ1UJ2;
  double DEta_BJ2UJ2;
  double DEta_BJ1UJ3;
  
  double cosDPhi_LepBJ1;
  double cosDPhi_LepBJ2;
  double cosDPhi_LepUJ1;
  double cosDPhi_LepUJ2;
  double cosDPhi_LepUJ3;
  double DR_LepBJ1;
  double DR_LepBJ2;
  double DR_LepUJ1;
  double DR_LepUJ2;
  double DR_LepUJ3;
  double DEta_LepBJ1;
  double DEta_LepBJ2;
  double DEta_LepUJ1;
  double DEta_LepUJ2;
  double DEta_LepUJ3;
  
  double Mass_Wlep;
  double Eta_Wlep;
  double Pt_Wlep;
  
  double Mass_Whad12;
  double Eta_Whad12;
  double Pt_Whad12;
  double Mass_Whad23;
  double Eta_Whad23;
  double Pt_Whad23;
  double Mass_Whad13;
  double Eta_Whad13;
  double Pt_Whad13;
  
  double Mass_TlepBJ1;
  double Eta_TlepBJ1;
  double Pt_TlepBJ1;
  double Mass_TlepBJ2;
  double Eta_TlepBJ2;
  double Pt_TlepBJ2;
  
  double Mass_Thad12BJ1;
  double Eta_Thad12BJ1;
  double Pt_Thad12BJ1;
  double Mass_Thad12BJ2;
  double Eta_Thad12BJ2;
  double Pt_Thad12BJ2;
  double Mass_Thad23BJ1;
  double Eta_Thad23BJ1;
  double Pt_Thad23BJ1;
  double Mass_Thad23BJ2;
  double Eta_Thad23BJ2;
  double Pt_Thad23BJ2;
  double Mass_Thad13BJ1;
  double Eta_Thad13BJ1;
  double Pt_Thad13BJ1;
  double Mass_Thad13BJ2;
  double Eta_Thad13BJ2;
  double Pt_Thad13BJ2;
  
  double HtBJets;
  double HtJets;
  double HtTot;
  double Shat;
  double Mass_Jets;
  double Mass_tot;
  double MetHtJets;
  
  double Sphericity;
  double Aplanarity;
  double Centrality;
  
  double cosLepWlepBJ1;
  double cosNuWlepBJ1;
  double cosLepWlepBJ2;
  double cosNuWlepBJ2;
  
  double cosUJ1Whad12BJ1;
  double cosUJ2Whad12BJ1;
  double cosUJ1Whad12BJ2;
  double cosUJ2Whad12BJ2;
  double cosUJ1Whad13BJ1;
  double cosUJ3Whad13BJ1;
  double cosUJ1Whad13BJ2;
  double cosUJ3Whad13BJ2;
  double cosUJ2Whad23BJ1;
  double cosUJ3Whad23BJ1;
  double cosUJ2Whad23BJ2;
  double cosUJ3Whad23BJ2;
  
  double cosLepTlepBJ1UJ1;
  double cosNuTlepBJ1UJ1;
  double cosWlepTlepBJ1UJ1;
  double cosBJTlepBJ1UJ1;
  double cosUJ1Thad12BJ1Wlep;
  double cosUJ2Thad12BJ1Wlep;
  double cosWhad12Thad12BJ1Wlep;
  double cosBJThad12BJ1Wlep;
  double cosLepTlepBJ1Whad12;
  double cosNuTlepBJ1Whad12;
  double cosWlepTlepBJ1Whad12;
  double cosBJTlepBJ1Whad12;
  double cosLepTlepBJ1Thad12BJ2;
  double cosNuTlepBJ1Thad12BJ2;
  double cosWlepTlepBJ1Thad12BJ2;
  double cosBJTlepBJ1Thad12BJ2;
  double cosLepTlepBJ2Thad12BJ1;
  double cosNuTlepBJ2Thad12BJ1;
  double cosWlepTlepBJ2Thad12BJ1;
  double cosBJTlepBJ2Thad12BJ1;
  double cosUJ1Thad12BJ1TlepBJ2;
  double cosUJ2Thad12BJ1TlepBJ2;
  double cosWhad12Thad12BJ1TlepBJ2;
  double cosBJThad12BJ1TlepBJ2;
  double cosUJ1Thad12BJ2TlepBJ1;
  double cosUJ2Thad12BJ2TlepBJ1;
  double cosWhad12Thad12BJ2TlepBJ1;
  double cosBJThad12BJ2TlepBJ1;
  double cosLepTlepBJ1BJ2;
  double cosNuTlepBJ1BJ2;
  double cosWlepTlepBJ1BJ2;
  double cosBJTlepBJ1BJ2;
  double cosLepTlepBJ2BJ1;
  double cosNuTlepBJ2BJ1;
  double cosWlepTlepBJ2BJ1;
  double cosBJTlepBJ2BJ1;
                    
};

#endif







