#ifndef SINGLETOPDPDMAKER_OVERLAPFILTER_H
#define SINGLETOPDPDMAKER_OVERLAPFILTER_H

#include <string>
#include <vector>
#include <map>

#include "GaudiKernel/Algorithm.h"
#include "GaudiKernel/MsgStream.h"
#include "StoreGate/StoreGate.h"

#include "EventKernel/INavigable4Momentum.h"
#include "NavFourMom/INavigable4MomentumCollection.h"
#include "FourMom/P4Help.h"

#include "egammaEvent/PhotonContainer.h"
#include "egammaEvent/Photon.h"
#include "egammaEvent/ElectronContainer.h"
#include "egammaEvent/Electron.h"
#include "muonEvent/MuonContainer.h"
#include "muonEvent/Muon.h"
#include "tauEvent/TauJetContainer.h"
#include "tauEvent/TauJet.h"
#include "JetEvent/JetCollection.h"
#include "JetEvent/Jet.h"
#include "CompositeParticleEvent/CompositeParticleContainer.h"
#include "CompositeParticleEvent/CompositeParticle.h"
#include "McParticleEvent/TruthParticleContainer.h"
#include "McParticleEvent/TruthParticle.h"

#include "SingleTopDPDMaker/SelectionInfoContainer.h"
#include "SingleTopDPDMaker/SelectionInfo.h"

class OverlapFilter : public Algorithm
{

public:

  OverlapFilter(const std::string& name, ISvcLocator* pSvcLocator);
  virtual ~OverlapFilter();
  
  StatusCode initialize();
  StatusCode finalize();
  StatusCode execute();
  
  StatusCode InitializeOverlapRemoval();
  StatusCode ExecuteOverlapRemoval(int);
  
  bool TestContainerType();
    
  template <class CT> bool StoreRootContainer(const CT*);
  template <class CT, class T> std::pair<int, int> RemoveOverlap(const CT*, T*, std::string, std::string, std::string, bool, double);
      
private:

  StoreGateSvc * aStoreGateSvc;
  
  int InputEventNumber;
  int OutputEventNumber;
  
  std::string RootContainerName;
  std::string RootContainerType;
    
  std::vector<std::string> InputContainerName;
  std::vector<std::string> OutputContainerName;
  std::vector<std::string> ContainerType;
  
  std::vector<std::string> SelectionInfoContainerName;
  std::vector<std::string> SelectionLabel;
  
  std::vector<bool> FilterSameContainerType;
    
  const PhotonContainer            * aPhotonContainer;
  const ElectronContainer          * aElectronContainer;
  const Analysis::MuonContainer    * aMuonContainer;
  const Analysis::TauJetContainer  * aTauJetContainer;
  const JetCollection              * aJetContainer;
  const CompositeParticleContainer * aCompositeParticleContainer;
  const TruthParticleContainer     * aTruthParticleContainer;
  
  Analysis::Photon   * aPhoton;
  Analysis::Electron * aElectron;
  Analysis::Muon     * aMuon;
  Analysis::TauJet   * aTauJet;
  Jet                * aJet;
  CompositeParticle  * aCompositeParticle;
  TruthParticle      * aTruthParticle;
            
  std::vector<std::pair <std::string, const INavigable4Momentum*> > ParticleContainer;
  
  std::vector<double> DeltaRCut;
  
  std::vector<int> InputObjectNumber;
  std::vector<int> OutputObjectNumber;
  
  std::vector<bool> Mask;
  
  SelectionInfoContainer * aSelectionInfoContainer;
                                   
};

#endif







