#ifndef SINGLETOPDPDMAKER_PHOTONSELECTION_H
#define SINGLETOPDPDMAKER_PHOTONSELECTION_H

#include <string>

#include "GaudiKernel/Algorithm.h"
#include "GaudiKernel/MsgStream.h"
#include "StoreGate/StoreGate.h"

#include "egammaEvent/PhotonContainer.h"
#include "egammaEvent/Photon.h"
#include "egammaEvent/egammaParamDefs.h"
#include "egammaEvent/egammaPIDdefs.h"
#include "egammaEvent/EMShower.h"

#include "SingleTopDPDMaker/SelectionInfoContainer.h"
#include "SingleTopDPDMaker/SelectionInfo.h"

class PhotonSelection : public Algorithm
{

public:

  PhotonSelection(const std::string& name, ISvcLocator* pSvcLocator);
    
  virtual ~PhotonSelection();
  
  StatusCode initialize();
  StatusCode finalize();
  StatusCode execute();
  
  void Select();
  
  bool TestAuthorOption();
  bool TestEmMaskOption();
  bool TestConeSizeOption();
  
  bool SelectPhoton(const Analysis::Photon*);
  
  bool TestAuthor  (const Analysis::Photon*);
  bool TestEmMask  (const Analysis::Photon*);
  bool TestEtCone  (const Analysis::Photon*);
  
private:

  StoreGateSvc * aStoreGateSvc;
  
  int InputEventNumber;
  int OutputEventNumber;
  
  int InputObjectNumber;
  int OutputObjectNumber;
  
  std::string InputContainerName;
  std::string OutputContainerName;
  
  std::string SelectionInfoContainerName;
  std::string SelectionLabel;
  
  const PhotonContainer * aInputContainer;
  PhotonContainer       * aOutputContainer;
  
  bool ApplyEtConeCut;
  
  std::string EmMask;
  std::string Author;
  
  double PtCut;
  double EtaCut;
  double ConeSize;
  double EtConeCut;
  
  egammaParameters::ParamDef ConeSizeParameter;
  
  std::vector<bool> Mask;
  
  SelectionInfoContainer * aSelectionInfoContainer;

};

#endif
