#ifndef SINGLETOPDPDMAKER_TAGGEDJETSELECTION_H
#define SINGLETOPDPDMAKER_TAGGEDJETSELECTION_H

#include <string>

#include "GaudiKernel/Algorithm.h"
#include "GaudiKernel/MsgStream.h"
#include "StoreGate/StoreGate.h"

#include "JetEvent/JetCollection.h"
#include "JetEvent/Jet.h"

#include "SingleTopDPDMaker/SelectionInfoContainer.h"
#include "SingleTopDPDMaker/SelectionInfo.h"

class TaggedJetSelection : public Algorithm
{

public:

  TaggedJetSelection(const std::string& name, ISvcLocator* pSvcLocator);
    
  virtual ~TaggedJetSelection();
  
  StatusCode initialize();
  StatusCode finalize();
  StatusCode execute();
  
  void Select();
  
  bool TestTaggingAlgorithmOption();
  
  bool SelectTaggedJet(const Jet*);
    
private:

  StoreGateSvc * aStoreGateSvc;
  
  int InputEventNumber;
  int OutputEventNumber;
  
  int InputObjectNumber;
  int OutputObjectNumber;
  
  std::string InputContainerName;
  std::string OutputContainerName;
  
  std::string SelectionInfoContainerName;
  std::string SelectionLabel;
  
  const JetCollection * aInputContainer;
  JetCollection       * aOutputContainer;
    
  double PtCut;
  double EtaCut;
  
  std::string TaggingAlgorithm;
  double TaggingWeightCut;
  
  std::vector<bool> Mask;
  
  SelectionInfoContainer * aSelectionInfoContainer;

};

#endif
