#ifndef SINGLETOPDPDMAKER_TAUJETSELECTION_H
#define SINGLETOPDPDMAKER_TAUJETSELECTION_H

#include <string>

#include "GaudiKernel/Algorithm.h"
#include "GaudiKernel/MsgStream.h"
#include "StoreGate/StoreGate.h"

#include "tauEvent/TauJetContainer.h"
#include "tauEvent/TauJet.h"
#include "tauEvent/TauJetParameters.h"
#include "tauEvent/TauPID.h"

#include "SingleTopDPDMaker/SelectionInfoContainer.h"
#include "SingleTopDPDMaker/SelectionInfo.h"

class TauJetSelection : public Algorithm
{

public:

  TauJetSelection(const std::string& name, ISvcLocator* pSvcLocator);
    
  virtual ~TauJetSelection();
  
  StatusCode initialize();
  StatusCode finalize();
  StatusCode execute();
  
  void Select();
  
  bool TestAuthorOption();
  bool TestTauFlagOption();
  bool TestDiscriminantName();
  
  bool SelectTauJet    (const Analysis::TauJet*);
  
  bool TestAuthor      (const Analysis::TauJet*);
  bool TestTauFlag     (const Analysis::TauJet*);
  bool TestDiscriminant(const Analysis::TauJet*);
    
private:

  StoreGateSvc * aStoreGateSvc;
  
  int InputEventNumber;
  int OutputEventNumber;
  
  int InputObjectNumber;
  int OutputObjectNumber;
  
  std::string InputContainerName;
  std::string OutputContainerName;
  
  std::string SelectionInfoContainerName;
  std::string SelectionLabel;
  
  const Analysis::TauJetContainer * aInputContainer;
  Analysis::TauJetContainer       * aOutputContainer;
  
  std::string Author;
  std::string TauFlag;
  
  std::vector<std::string>DiscriminantName;
  std::vector<std::string>DiscriminantType;
    
  double PtCut;
  double EtaCut;
  double MinTrackNumber;
  double MaxTrackNumber;
  double HadronicEtFractionCut;
  
  std::vector<double> DiscriminantCut;
  
  std::vector<TauJetParameters::TauID> DiscriminantIdent;
  
  std::vector<bool> Mask;
  
  SelectionInfoContainer * aSelectionInfoContainer;
  
};

#endif
