#ifndef SINGLETOPDPDMAKER_TRIGGERDECISIONFILTER_H
#define SINGLETOPDPDMAKER_TRIGGERDECISIONFILTER_H

#include <string>
#include <vector>
#include <map>

#include "GaudiKernel/Algorithm.h"
#include "GaudiKernel/MsgStream.h"
#include "GaudiKernel/ToolHandle.h"
#include "StoreGate/StoreGate.h"

#include "TrigDecision/TrigDecisionTool.h"

#include "SingleTopDPDMaker/TriggerDecisionInfo.h"

class TriggerDecisionFilter : public Algorithm
{

public:

  TriggerDecisionFilter(const std::string& name, ISvcLocator* pSvcLocator);
  virtual ~TriggerDecisionFilter();

  StatusCode initialize();
  StatusCode execute();
  StatusCode finalize();
  
  bool SelectDecision();
  
  void GetDecision();
  void RecordDecision();

private:

  StoreGateSvc * aStoreGateSvc;

  int InputEventNumber;
  int OutputEventNumber;
  
  std::string TriggerDecisionInfoName;
  
  std::vector<std::string> AcceptedChainName;
  std::vector<std::string> SelectedChainName;
          
  ToolHandle<TrigDec::TrigDecisionTool> aTriggerDecisionTool;
  
  std::vector<std::string> Level1Names;
  std::vector<std::string> Level2Names;
  std::vector<std::string> EventFilterNames;
  
  bool PassedTrigger;
  bool PassedLevel1;
  bool PassedLevel2;
  bool PassedEventFilter;
  
  std::map<std::string, bool> PassedChain;
  std::map<std::string, int>  PassedSelectedChain;
  
  TriggerDecisionInfo * aTriggerDecisionInfo;

};

#endif
