#ifndef SINGLETOPDPDMAKER_TRIGGERTREEMAKER_H
#define SINGLETOPDPDMAKER_TRIGGERTREEMAKER_H

#include <string>
#include <vector>
#include <map>

#include "GaudiKernel/Algorithm.h"
#include "GaudiKernel/MsgStream.h"
#include "GaudiKernel/ITHistSvc.h"
#include "StoreGate/StoreGate.h"

#include "TTree.h"

#include "SingleTopDPDMaker/TriggerDecisionInfo.h"

class TriggerTreeMaker : public Algorithm
{

public:

  TriggerTreeMaker(const std::string& name, ISvcLocator* pSvcLocator);
  virtual ~TriggerTreeMaker();
  
  StatusCode initialize();
  StatusCode finalize();
  StatusCode execute();
  
  void SetBranches();
  void DeleteBranches();
  void ClearBranches();
  void FillBranches();
  
// TriggerDecisionTree.cxx
  
  void SetDecisionBranches();
  void ClearDecisionBranches();
  void FillDecisionBranches();
                  
private:

  StoreGateSvc * aStoreGateSvc;
  ITHistSvc    * aTHistSvc;
  TTree        * aTree;
  
  int InputEventNumber;
  int OutputEventNumber;
  
  std::string TreeName;
  
  std::string TriggerDecisionInfoName;
  std::string TriggerDecisionInfoLabel;
          
  const TriggerDecisionInfo * aTriggerDecisionInfo;
  
  #include "TriggerDecisionTree.h"
                            
};

#endif







