#ifndef SINGLETOPDPDMAKER_TRUTHPARTICLESELECTION_H
#define SINGLETOPDPDMAKER_TRUTHPARTICLESELECTION_H

#include <string>
#include <vector>

#include "GaudiKernel/Algorithm.h"
#include "GaudiKernel/MsgStream.h"
#include "StoreGate/StoreGate.h"

#include "McParticleEvent/TruthParticleContainer.h"
#include "McParticleEvent/TruthParticle.h"
#include "McParticleEvent/TruthParticleParamDefs.h"

#include "GeneratorObjects/McEventCollection.h"

#include "TruthHelper/IsGenerator.h"
#include "TruthHelper/IsGenStable.h"

#include "HepMC/GenParticle.h"
#include "HepMC/GenVertex.h"

#include "SingleTopDPDMaker/SelectionInfoContainer.h"
#include "SingleTopDPDMaker/SelectionInfo.h"

class TruthParticleSelection : public Algorithm
{

public:

  TruthParticleSelection(const std::string& name, ISvcLocator* pSvcLocator);
    
  virtual ~TruthParticleSelection();
  
  StatusCode initialize();
  StatusCode finalize();
  StatusCode execute();
  
  void Select();
  
  bool SelectTruthParticle(const TruthParticle*);
    
private:

  StoreGateSvc * aStoreGateSvc;
  
  int InputEventNumber;
  int OutputEventNumber;
  
  int InputObjectNumber;
  int OutputObjectNumber;
  
  std::string McEventContainerName;
  std::string InputContainerName;
  std::string OutputContainerName;
  
  std::string SelectionInfoContainerName;
  std::string SelectionLabel;
  
  const TruthParticleContainer * aInputContainer;
  TruthParticleContainer       * aOutputContainer;
  
  bool ApplyIsStableCut;
  bool ApplyIsGeneratorCut;
  bool ApplySelfDecayCut;
  
  std::vector<int> PdgId;
  std::vector<int> Status;
  std::vector<int> VetoStatus;
  
  double PtCut; 
  double EtaCut;  
  
  std::vector<bool> Mask;
  
  SelectionInfoContainer * aSelectionInfoContainer;

};

#endif
