#ifndef SINGLETOPDPDMAKER_TRUTHTREEMAKER_H
#define SINGLETOPDPDMAKER_TRUTHTREEMAKER_H

#include <string>
#include <vector>
#include <map>

#include "GaudiKernel/Algorithm.h"
#include "GaudiKernel/MsgStream.h"
#include "GaudiKernel/ITHistSvc.h"
#include "StoreGate/StoreGate.h"

#include "MissingETEvent/MissingEtTruth.h"
#include "McParticleEvent/TruthParticleContainer.h"
#include "McParticleEvent/TruthParticle.h"

#include "GeneratorObjects/McEventCollection.h"

#include "TTree.h"

class TruthTreeMaker : public Algorithm
{

public:

  TruthTreeMaker(const std::string& name, ISvcLocator* pSvcLocator);
  virtual ~TruthTreeMaker();
  
  StatusCode initialize();
  StatusCode finalize();
  StatusCode execute();
  
  bool TestMissingEtSource();
  bool TestContainerType();
  bool TestContainerLabel();
  
  void SetBranches();
  void DeleteBranches();
  void ClearBranches();
  void FillBranches();
    
// TruthMissingEtTree.cxx

  void SetMissingEt();
  void ClearMissingEt();
  void FillMissingEt();
  
// TruthParticleTree.cxx

  void SetParticles();
  void DeleteParticles();
  void ClearParticles();
  void FillParticles();
  
  void GetParentParticles(const TruthParticle*, std::vector<const TruthParticle*>&);
  void GetDecayParticles (const TruthParticle*, std::vector<const TruthParticle*>&);
    
private:

  StoreGateSvc * aStoreGateSvc;
  ITHistSvc    * aTHistSvc;
  TTree        * aTree;
  
  int InputEventNumber;
  int OutputEventNumber;
    
// Input Containers
        
  std::string McEventContainerName;
  
  std::vector<std::string> MissingEtName;
  std::vector<std::string> MissingEtLabel;
  std::vector<std::string> MissingEtSource;
  
  std::vector<MissingEtTruth::TruthIndex> MissingEtIndex;
  
  std::vector<std::string> ContainerName;
  std::vector<std::string> ContainerLabel;
  
  std::vector<std::string> ParticleContainerName;
  std::vector<std::string> ParticleContainerLabel;

  std::map<std::string, const MissingEtTruth*> aMissingEt;
    
  std::map<std::string, const TruthParticleContainer*> aParticleContainer;
    
// Output Tree
  
  std::string TreeName;
    
  #include "TruthMissingEtTree.h"
  #include "TruthParticleTree.h"
            
};

#endif







