#include "SingleTopDPDMaker/EFTriggerSelection.h"

EFTriggerSelection::EFTriggerSelection(const std::string& name, ISvcLocator* pSvcLocator) : Algorithm(name, pSvcLocator)
{

  declareProperty("OutputContainerName", OutputContainerName);
            
}

EFTriggerSelection::~EFTriggerSelection(){}

StatusCode EFTriggerSelection::initialize()
{
  
  MsgStream MsgLog(messageService(), name());
  
  MsgLog << MSG::INFO << "Initializing " << name() << endreq;
        
  bool isTestContainerSize = OutputContainerName.size() > 0;
  
  if(!isTestContainerSize)
  {
    MsgLog << MSG::FATAL << "Wrong Container Size Properties" << endreq;
    return StatusCode::FAILURE;
  }
  
  bool isTestContainerType = this->TestContainerType();
      
  if(!isTestContainerType)
  {
    MsgLog << MSG::FATAL << "Wrong Container Type Properties" << endreq;
    return StatusCode::FAILURE;
  }
  
  for(unsigned int i=0; i<OutputContainerName.size(); i++)
  {
    MsgLog << MSG::INFO << "Output Container Name = " << OutputContainerName[i] << endreq;
  }
            
  StatusCode status = service("StoreGateSvc", aStoreGateSvc);

  if(status.isFailure()) 
  {
    MsgLog << MSG::FATAL << "StoreGateSvc Unavailable" << endreq;
    return StatusCode::FAILURE;
  }
  
  InputEventNumber  = 0;
  OutputEventNumber = 0;
        
  return StatusCode::SUCCESS;
  
}

StatusCode EFTriggerSelection::finalize()
{

  MsgStream MsgLog(msgSvc(), name());
  
  MsgLog << MSG::INFO << "Finalizing " << name() << endreq;
  
  MsgLog << MSG::INFO << "Input  Event Number = " << InputEventNumber  << endreq;
  MsgLog << MSG::INFO << "Output Event Number = " << OutputEventNumber << endreq;
  
  return StatusCode::SUCCESS;
  
}

bool EFTriggerSelection::TestContainerType()
{
  
  for(unsigned int i=0; i<OutputContainerName.size(); i++)
  {
    
    std::string Name = OutputContainerName[i];
    
    if(Name.find("EF", 0) == std::string::npos) return false;
    
    if(Name.find("Electron", 0) != std::string::npos) 
    {
      isEgamma = true;
      EgammaContainerName = Name;
    }
    
    else if(Name.find("Muon", 0) != std::string::npos) 
    {
      isMuon = true;
      MuonContainerName = Name;
    }
    
    else if(Name.find("Tau", 0) != std::string::npos) 
    {
      isTau = true;
      TauContainerName = Name;
    }
    
    else if(Name.find("BJet", 0) != std::string::npos) 
    {
      isBJet = true;
      BJetContainerName = Name;
    }
    else if(Name.find("Jet", 0) != std::string::npos) 
    {
      isJet = true;
      JetContainerName = Name;
    }
    
    else return false;
        
  }
    
  return true;

}

StatusCode EFTriggerSelection::execute()
{
  
  InputEventNumber++;
  
  StatusCode status;
  
  if(isEgamma) 
  {
    status = this->executeEgamma();
    if(status.isFailure()) return StatusCode::FAILURE;
  }
    
  if(isMuon)
  {
    status = this->executeMuon();
    if(status.isFailure()) return StatusCode::FAILURE;
  }
  
  if(isTau)
  {
    status = this->executeTau();
    if(status.isFailure()) return StatusCode::FAILURE;
  }
  
  if(isJet)
  {
    status = this->executeJet();
    if(status.isFailure()) return StatusCode::FAILURE;
  }
  
  if(isBJet)
  {
    status = this->executeBJet();
    if(status.isFailure()) return StatusCode::FAILURE;
  }
  
  setFilterPassed(true);
  
  OutputEventNumber++;
  
  return StatusCode::SUCCESS;
  
}

template <class CT, class T> bool EFTriggerSelection::Select(const CT * aContainer, T * aObject,
std::string OutputContainerName)
{
/*  
  StatusCode status;
  
  const DataHandle<CT> ItrB;
  const DataHandle<CT> ItrE;
  
  status = aStoreGateSvc->retrieve(ItrB, ItrE);
  if(status.isFailure()) return false;
    
  INavigable4MomentumCollection * aContainer = new INavigable4MomentumCollection(SG::VIEW_ELEMENTS);
    
  status = aStoreGateSvc->record(aContainer, OutputContainerName);
  if(status.isFailure()) return false;
    
  DataHandle<CT> ContainerItr;
    
  for(ContainerItr=ItrB; ContainerItr!=ItrE; ContainerItr++)
  {
      
    typename CT::const_iterator Itr;
    
    for(Itr=(ContainerItr.cptr())->begin(); Itr!=(ContainerItr.cptr())->end(); Itr++)
    {
      T * aObject = const_cast<T*>(*Itr);
      aContainer->push_back(aObject);
    }
          
  }
    
  status = aStoreGateSvc->setConst(aContainer);
  if(status.isFailure()) return false;
      
  return true;
*/    
}

StatusCode EFTriggerSelection::executeEgamma()
{

  MsgStream MsgLog(msgSvc(), name());
  
  StatusCode status;
  
  status = aStoreGateSvc->retrieve(EgammaItrB, EgammaItrE);
  
  if(status.isFailure())
  {
    MsgLog << MSG::FATAL << "No Input Egamma Container Available" << endreq;
    return StatusCode::FAILURE;
  }
    
  aEgammaContainer = new INavigable4MomentumCollection(SG::VIEW_ELEMENTS);
    
  status = aStoreGateSvc->record(aEgammaContainer, EgammaContainerName);
    
  if(status.isFailure())
  {
    MsgLog << MSG::FATAL << "Output Egamma Container Unavailable" << endreq;
    return StatusCode::FAILURE;
  }
    
  this->SelectEgammas();
    
  status = aStoreGateSvc->setConst(aEgammaContainer);
    
  if(status.isFailure())
  {
    MsgLog << MSG::FATAL << "Output Egamma Container Unavailable" << endreq;
    return StatusCode::FAILURE;
  }
  
  return StatusCode::SUCCESS;
    
}

StatusCode EFTriggerSelection::executeMuon()
{

  MsgStream MsgLog(msgSvc(), name());
  
  StatusCode status;
  
  status = aStoreGateSvc->retrieve(MuonItrB, MuonItrE);
  
  if(status.isFailure())
  {
    MsgLog << MSG::FATAL << "No Input Muon Container Available" << endreq;
    return StatusCode::FAILURE;
  }
    
  aMuonContainer = new INavigable4MomentumCollection(SG::VIEW_ELEMENTS);
    
  status = aStoreGateSvc->record(aMuonContainer, MuonContainerName);
    
  if(status.isFailure())
  {
    MsgLog << MSG::FATAL << "Output Muon Container Unavailable" << endreq;
    return StatusCode::FAILURE;
  }
    
  this->SelectMuons();
    
  status = aStoreGateSvc->setConst(aMuonContainer);
    
  if(status.isFailure())
  {
    MsgLog << MSG::FATAL << "Output Muon Container Unavailable" << endreq;
    return StatusCode::FAILURE;
  }
  
  return StatusCode::SUCCESS;
    
}

StatusCode EFTriggerSelection::executeTau()
{

  MsgStream MsgLog(msgSvc(), name());
  
  StatusCode status;
  
  status = aStoreGateSvc->retrieve(TauItrB, TauItrE);
  
  if(status.isFailure())
  {
    MsgLog << MSG::FATAL << "No Input Tau Container Available" << endreq;
    return StatusCode::FAILURE;
  }
    
  aTauContainer = new INavigable4MomentumCollection(SG::VIEW_ELEMENTS);
    
  status = aStoreGateSvc->record(aTauContainer, TauContainerName);
    
  if(status.isFailure())
  {
    MsgLog << MSG::FATAL << "Output Tau Container Unavailable" << endreq;
    return StatusCode::FAILURE;
  }
    
  this->SelectTaus();
    
  status = aStoreGateSvc->setConst(aTauContainer);
    
  if(status.isFailure())
  {
    MsgLog << MSG::FATAL << "Output Tau Container Unavailable" << endreq;
    return StatusCode::FAILURE;
  }
  
  return StatusCode::SUCCESS;
    
}

StatusCode EFTriggerSelection::executeJet()
{

  MsgStream MsgLog(msgSvc(), name());
  
  StatusCode status;
  
  status = aStoreGateSvc->retrieve(JetItrB, JetItrE);
  
  if(status.isFailure())
  {
    MsgLog << MSG::FATAL << "No Input Jet Container Available" << endreq;
    return StatusCode::FAILURE;
  }
    
  aJetContainer = new INavigable4MomentumCollection(SG::VIEW_ELEMENTS);
    
  status = aStoreGateSvc->record(aJetContainer, JetContainerName);
    
  if(status.isFailure())
  {
    MsgLog << MSG::FATAL << "Output Jet Container Unavailable" << endreq;
    return StatusCode::FAILURE;
  }
    
  this->SelectJets();
    
  status = aStoreGateSvc->setConst(aJetContainer);
    
  if(status.isFailure())
  {
    MsgLog << MSG::FATAL << "Output Jet Container Unavailable" << endreq;
    return StatusCode::FAILURE;
  }
  
  return StatusCode::SUCCESS;
    
}

StatusCode EFTriggerSelection::executeBJet()
{

  MsgStream MsgLog(msgSvc(), name());
  
  StatusCode status;
  
  status = aStoreGateSvc->retrieve(BJetItrB, BJetItrE);
  
  if(status.isFailure())
  {
    MsgLog << MSG::FATAL << "No Input BJet Container Available" << endreq;
    return StatusCode::FAILURE;
  }
    
  aBJetContainer = new INavigable4MomentumCollection(SG::VIEW_ELEMENTS);
    
  status = aStoreGateSvc->record(aBJetContainer, BJetContainerName);
    
  if(status.isFailure())
  {
    MsgLog << MSG::FATAL << "Output BJet Container Unavailable" << endreq;
    return StatusCode::FAILURE;
  }
    
  this->SelectBJets();
    
  status = aStoreGateSvc->setConst(aBJetContainer);
    
  if(status.isFailure())
  {
    MsgLog << MSG::FATAL << "Output BJet Container Unavailable" << endreq;
    return StatusCode::FAILURE;
  }
  
  return StatusCode::SUCCESS;
    
}
  
void EFTriggerSelection::SelectEgammas()
{

  DataHandle<egammaContainer> ContainerItr;
    
  for(ContainerItr=EgammaItrB; ContainerItr!=EgammaItrE; ContainerItr++)
  {
      
    egammaContainer::const_iterator Itr;
    
    for(Itr=(ContainerItr.cptr())->begin(); Itr!=(ContainerItr.cptr())->end(); Itr++)
    {
      egamma * aEgamma = const_cast<egamma*>(*Itr);
      aEgammaContainer->push_back(aEgamma);
    }
          
  }
      
}

void EFTriggerSelection::SelectMuons()
{

  DataHandle<TrigMuonEFContainer> ContainerItr;
    
  for(ContainerItr=MuonItrB; ContainerItr!=MuonItrE; ContainerItr++)
  {
             
    TrigMuonEFContainer::const_iterator Itr;
    
    for(Itr=(ContainerItr.cptr())->begin(); Itr!=(ContainerItr.cptr())->end(); Itr++)
    {
    
      TrigMuonEF * aMuon = const_cast<TrigMuonEF*>(*Itr);
      aMuonContainer->push_back(aMuon);
	
    }
          
  }
      
}

void EFTriggerSelection::SelectTaus()
{

  DataHandle<Analysis::TauJetContainer> ContainerItr;
    
  for(ContainerItr=TauItrB; ContainerItr!=TauItrE; ContainerItr++)
  {
  
    Analysis::TauJetContainer::const_iterator Itr;
    
    for(Itr=(ContainerItr.cptr())->begin(); Itr!=(ContainerItr.cptr())->end(); Itr++)
    {
      Analysis::TauJet * aTau = const_cast<Analysis::TauJet*>(*Itr);
      aTauContainer->push_back(aTau);
    }
    
  }
      
}

void EFTriggerSelection::SelectJets()
{

  DataHandle<JetCollection> ContainerItr;
    
  for(ContainerItr=JetItrB; ContainerItr!=JetItrE; ContainerItr++)
  {
    
    JetCollection::const_iterator Itr;
    
    for(Itr=(ContainerItr.cptr())->begin(); Itr!=(ContainerItr.cptr())->end(); Itr++)
    {
      Jet * aJet = const_cast<Jet*>(*Itr);
      aJetContainer->push_back(aJet);
    }
    
  }
      
}

void EFTriggerSelection::SelectBJets()
{

  DataHandle<TrigEFBjetContainer> ContainerItr;
    
  for(ContainerItr=BJetItrB; ContainerItr!=BJetItrE; ContainerItr++)
  {
    
    TrigEFBjetContainer::const_iterator Itr;
    
    for(Itr=(ContainerItr.cptr())->begin(); Itr!=(ContainerItr.cptr())->end(); Itr++)
    {
      TrigEFBjet * aBJet = const_cast<TrigEFBjet*>(*Itr);
      aBJetContainer->push_back(aBJet);
    }
    
  }
    
}
