#include "SingleTopDPDMaker/ElectronEtaCrackFilter.h"

ElectronEtaCrackFilter::ElectronEtaCrackFilter(const std::string& name, ISvcLocator* pSvcLocator) : Algorithm(name, pSvcLocator)
{

  declareProperty("ElectronContainerName", ElectronContainerName = "ElectronAODCollection");
  
  declareProperty("MinEtaCrack", MinEtaCrack = 1.37);
  declareProperty("MaxEtaCrack", MaxEtaCrack = 1.52);
  
  declareProperty("MinNumber", MinNumber);
  declareProperty("MaxNumber", MaxNumber);
             
}

ElectronEtaCrackFilter::~ElectronEtaCrackFilter(){}

StatusCode ElectronEtaCrackFilter::initialize()
{
  
  MsgStream MsgLog(msgSvc(), name());
  
  MsgLog << MSG::INFO << "Initializing " << name() << endreq;
  
  MsgLog << MSG::INFO << "Electron Container Name = " << ElectronContainerName << endreq;
  
  MsgLog << MSG::INFO << "Min Eta Crack = " << MinEtaCrack << endreq;
  MsgLog << MSG::INFO << "Max Eta Crack = " << MaxEtaCrack << endreq;
  
  MsgLog << MSG::INFO << "Min Number = " << MinNumber << endreq;
  MsgLog << MSG::INFO << "Max Number = " << MaxNumber << endreq;
   
  StatusCode status = service("StoreGateSvc", aStoreGateSvc);

  if(status.isFailure()) 
  {
    MsgLog << MSG::FATAL << "StoreGateSvc Unavailable" << endreq;
    return StatusCode::FAILURE;
  }
                        
  InputEventNumber  = 0;
  OutputEventNumber = 0;
  
  return StatusCode::SUCCESS;
  
}

StatusCode ElectronEtaCrackFilter::finalize()
{

  MsgStream MsgLog(msgSvc(), name());
  
  MsgLog << MSG::INFO << "Finalizing " << name() << endreq;
  
  MsgLog << MSG::INFO << "Input  Event Number = " << InputEventNumber  << endreq;
  MsgLog << MSG::INFO << "Output Event Number = " << OutputEventNumber << endreq;
          
  return StatusCode::SUCCESS;
  
}

StatusCode ElectronEtaCrackFilter::execute()
{

  MsgStream MsgLog(msgSvc(), name());
    
  InputEventNumber++;
  
  StatusCode status = aStoreGateSvc->retrieve(aElectronContainer, ElectronContainerName);
  
  if(status.isFailure())
  {
    MsgLog << MSG::FATAL << "Electron Container Unavailable" << endreq;
    return StatusCode::FAILURE;
  }
  
  int Size = 0;
  
  ElectronContainer::const_iterator Itr;
  
  for(Itr=aElectronContainer->begin(); Itr!= aElectronContainer->end(); Itr++)
  {
    const Analysis::Electron * aElectron = *Itr;
    bool isEtaCrack = (fabs(aElectron->eta()) >= MinEtaCrack) && (fabs(aElectron->eta()) <= MaxEtaCrack);
    if(isEtaCrack) Size++;
  }
  
  bool isSelected = (Size >= MinNumber) && (Size <= MaxNumber);
                
  if(isSelected) OutputEventNumber++;
  
  setFilterPassed(isSelected);
    
  return StatusCode::SUCCESS;
  
}
