#include "SingleTopDPDMaker/TreeMaker.h"

void TreeMaker::SetElectrons()
{

  std::vector<std::string>::const_iterator Itr;
  
  for(Itr=ElectronContainerLabel.begin(); Itr!=ElectronContainerLabel.end(); Itr++)
  {
  
    std::string Label = *Itr;

    Electron_pdgId[Label]  = new std::vector<double>;
    Electron_m[Label]      = new std::vector<double>;
    Electron_charge[Label] = new std::vector<double>;
    Electron_E[Label]      = new std::vector<double>;
    Electron_p_T[Label]    = new std::vector<double>;
    Electron_phi[Label]    = new std::vector<double>;
    Electron_eta[Label]    = new std::vector<double>;
    Electron_px[Label]     = new std::vector<double>;
    Electron_py[Label]     = new std::vector<double>;
    Electron_pz[Label]     = new std::vector<double>;
  
    Electron_IsEM[Label]                = new std::vector<int>;
    Electron_author[Label]              = new std::vector<int>;
    Electron_ElectronWeight[Label]      = new std::vector<double>;
    Electron_BgWeight[Label]            = new std::vector<double>;
    Electron_NeuralNet[Label]           = new std::vector<double>;
    Electron_Hmatrix[Label]             = new std::vector<double>;
    Electron_Hmatrix5[Label]            = new std::vector<double>;
    Electron_SofteIsEM[Label]           = new std::vector<int>;
    Electron_SofteBgWeight[Label]       = new std::vector<double>;
    Electron_SofteNeuralNet[Label]      = new std::vector<double>;
    Electron_IsolationLikelihood[Label] = new std::vector<double>;
    Electron_AdaBoost[Label]            = new std::vector<double>;
    Electron_LastEgammaPID[Label]       = new std::vector<double>;
    
    Electron_etcone20[Label] = new std::vector<double>;
    
    std::string N  = Label+"_"+"N";
    std::string NI = N+"/I";
        
    aTree->Branch(N.c_str(), &Electron_N[Label], NI.c_str());
    
    std::string pdgId  = Label+"_"+"pdgId";
    std::string m      = Label+"_"+"m";
    std::string charge = Label+"_"+"charge";
    std::string E      = Label+"_"+"E";
    std::string p_T    = Label+"_"+"p_T";
    std::string phi    = Label+"_"+"phi";
    std::string eta    = Label+"_"+"eta";
    std::string px     = Label+"_"+"px";
    std::string py     = Label+"_"+"py";
    std::string pz     = Label+"_"+"pz";
        
    aTree->Branch(pdgId.c_str(),  &Electron_pdgId[Label] );
    aTree->Branch(m.c_str(),      &Electron_m[Label]     );
    aTree->Branch(charge.c_str(), &Electron_charge[Label]);
    aTree->Branch(E.c_str(),      &Electron_E[Label]     );
    aTree->Branch(p_T.c_str(),    &Electron_p_T[Label]   );
    aTree->Branch(phi.c_str(),    &Electron_phi[Label]   );
    aTree->Branch(eta.c_str(),    &Electron_eta[Label]   );
    aTree->Branch(px.c_str(),     &Electron_px[Label]    );
    aTree->Branch(py.c_str(),     &Electron_py[Label]    );
    aTree->Branch(pz.c_str(),     &Electron_pz[Label]    );
    
    std::string IsEM                = Label+"_"+"IsEM";
    std::string author              = Label+"_"+"author";
    std::string ElectronWeight      = Label+"_"+"ElectronWeight";
    std::string BgWeight            = Label+"_"+"BgWeight";
    std::string NeuralNet           = Label+"_"+"NeuralNet";
    std::string Hmatrix             = Label+"_"+"Hmatrix";
    std::string Hmatrix5            = Label+"_"+"Hmatrix5";
    std::string SofteIsEM           = Label+"_"+"SofteIsEM";
    std::string SofteBgWeight       = Label+"_"+"SofteBgWeight";
    std::string SofteNeuralNet      = Label+"_"+"SofteNeuralNet";
    std::string IsolationLikelihood = Label+"_"+"IsolationLikelihood";
    std::string AdaBoost            = Label+"_"+"AdaBoost";
    std::string LastEgammaPID       = Label+"_"+"LastEgammaPID";
  
    aTree->Branch(IsEM.c_str(),                &Electron_IsEM[Label]               );
    aTree->Branch(author.c_str(),              &Electron_author[Label]             );
    aTree->Branch(ElectronWeight.c_str(),      &Electron_ElectronWeight[Label]     );
    aTree->Branch(BgWeight.c_str(),            &Electron_BgWeight[Label]           );
    aTree->Branch(NeuralNet.c_str(),           &Electron_NeuralNet[Label]          );
    aTree->Branch(Hmatrix.c_str(),             &Electron_Hmatrix[Label]            );
    aTree->Branch(Hmatrix5.c_str(),            &Electron_Hmatrix5[Label]           );
    aTree->Branch(SofteIsEM.c_str(),           &Electron_SofteIsEM[Label]          );
    aTree->Branch(SofteBgWeight.c_str(),       &Electron_SofteBgWeight[Label]      );
    aTree->Branch(SofteNeuralNet.c_str(),      &Electron_SofteNeuralNet[Label]     );
    aTree->Branch(IsolationLikelihood.c_str(), &Electron_IsolationLikelihood[Label]);
    aTree->Branch(AdaBoost.c_str(),            &Electron_AdaBoost[Label]           );
    aTree->Branch(LastEgammaPID.c_str(),       &Electron_LastEgammaPID[Label]      );
    
    std::string etcone20 = Label+"_"+"etcone20";
    
    aTree->Branch(etcone20.c_str(), &Electron_etcone20[Label]);
      
  }
    
}

void TreeMaker::DeleteElectrons()
{

  std::vector<std::string>::const_iterator Itr;
  
  for(Itr=ElectronContainerLabel.begin(); Itr!=ElectronContainerLabel.end(); Itr++)
  {
  
    std::string Label = *Itr;

    delete Electron_pdgId[Label];
    delete Electron_m[Label];
    delete Electron_charge[Label];
    delete Electron_E[Label];
    delete Electron_p_T[Label];
    delete Electron_phi[Label];
    delete Electron_eta[Label];
    delete Electron_px[Label];
    delete Electron_py[Label];
    delete Electron_pz[Label];
  
    delete Electron_IsEM[Label];
    delete Electron_author[Label];
    delete Electron_ElectronWeight[Label];
    delete Electron_BgWeight[Label];
    delete Electron_NeuralNet[Label];
    delete Electron_Hmatrix[Label];
    delete Electron_Hmatrix5[Label];
    delete Electron_SofteIsEM[Label];
    delete Electron_SofteBgWeight[Label];
    delete Electron_SofteNeuralNet[Label];
    delete Electron_IsolationLikelihood[Label];
    delete Electron_AdaBoost[Label];
    delete Electron_LastEgammaPID[Label];
    
    delete Electron_etcone20[Label];
    
  }
      
}

void TreeMaker::ClearElectrons()
{

  std::vector<std::string>::const_iterator Itr;
  
  for(Itr=ElectronContainerLabel.begin(); Itr!=ElectronContainerLabel.end(); Itr++)
  {
  
    std::string Label = *Itr;

    Electron_N[Label] = 0;

    Electron_pdgId[Label]->clear();
    Electron_m[Label]->clear();
    Electron_charge[Label]->clear();
    Electron_E[Label]->clear();
    Electron_p_T[Label]->clear();
    Electron_phi[Label]->clear();
    Electron_eta[Label]->clear();
    Electron_px[Label]->clear();
    Electron_py[Label]->clear();
    Electron_pz[Label]->clear();
  
    Electron_IsEM[Label]->clear();
    Electron_author[Label]->clear();
    Electron_ElectronWeight[Label]->clear();
    Electron_BgWeight[Label]->clear();
    Electron_NeuralNet[Label]->clear();
    Electron_Hmatrix[Label]->clear();
    Electron_Hmatrix5[Label]->clear();
    Electron_SofteIsEM[Label]->clear();
    Electron_SofteBgWeight[Label]->clear();
    Electron_SofteNeuralNet[Label]->clear();
    Electron_IsolationLikelihood[Label]->clear();
    Electron_AdaBoost[Label]->clear();
    Electron_LastEgammaPID[Label]->clear();
    
    Electron_etcone20[Label]->clear();
    
  }
  
}

void TreeMaker::FillElectrons()
{

  std::vector<std::string>::const_iterator Itr;
  
  for(Itr=ElectronContainerLabel.begin(); Itr!=ElectronContainerLabel.end(); Itr++)
  {
  
    std::string Label = *Itr;

    ElectronContainer::const_iterator cItr;
  
    for(cItr=aElectronContainer[Label]->begin(); cItr!=aElectronContainer[Label]->end(); cItr++)
    {
    
      const Analysis::Electron * aElectron = *cItr;
      
      if(aElectron->pt() <= ElectronPtCut[Label]) continue;
                             
      Electron_pdgId[Label]->push_back( aElectron->pdgId()  );
      Electron_m[Label]->push_back(     aElectron->m()      );
      Electron_charge[Label]->push_back(aElectron->charge() );
      Electron_E[Label]->push_back(     aElectron->e()/GeV  );
      Electron_p_T[Label]->push_back(   aElectron->pt()/GeV );
      Electron_phi[Label]->push_back(   aElectron->phi()    );
      Electron_eta[Label]->push_back(   aElectron->eta()    );
      Electron_px[Label]->push_back(    aElectron->px()/GeV );
      Electron_py[Label]->push_back(    aElectron->py()/GeV );
      Electron_pz[Label]->push_back(    aElectron->pz()/GeV );
    
      int IsEM      = static_cast<int>(aElectron->egammaID(egammaPID::IsEM)     );
      int SofteIsEM = static_cast<int>(aElectron->egammaID(egammaPID::SofteIsEM));
    
      Electron_IsEM[Label]->push_back(               IsEM                                               );
      Electron_author[Label]->push_back(             aElectron->author()                                );
      Electron_ElectronWeight[Label]->push_back(     aElectron->egammaID(egammaPID::ElectronWeight)     );
      Electron_BgWeight[Label]->push_back(           aElectron->egammaID(egammaPID::BgWeight)           );
      Electron_NeuralNet[Label]->push_back(          aElectron->egammaID(egammaPID::NeuralNet)          );
      Electron_Hmatrix[Label]->push_back(            aElectron->egammaID(egammaPID::Hmatrix)            );
      Electron_Hmatrix5[Label]->push_back(           aElectron->egammaID(egammaPID::Hmatrix5)           );
      Electron_SofteIsEM[Label]->push_back(          SofteIsEM                                          );
      Electron_SofteBgWeight[Label]->push_back(      aElectron->egammaID(egammaPID::SofteBgWeight)      );
      Electron_SofteNeuralNet[Label]->push_back(     aElectron->egammaID(egammaPID::SofteNeuralNet)     );
      Electron_IsolationLikelihood[Label]->push_back(aElectron->egammaID(egammaPID::IsolationLikelihood));
      Electron_AdaBoost[Label]->push_back(           aElectron->egammaID(egammaPID::AdaBoost)           );
      Electron_LastEgammaPID[Label]->push_back(      aElectron->egammaID(egammaPID::LastEgammaPID)      );
        
      const EMShower * aEMShower = aElectron->detail<EMShower>("egDetailAOD");
    
      if(aEMShower) Electron_etcone20[Label]->push_back(aEMShower->parameter(egammaParameters::etcone20)/GeV);
      else          Electron_etcone20[Label]->push_back(-1);
    
    }
    
    Electron_N[Label] = Electron_E[Label]->size();
    
  }
  
}
