#include "SingleTopDPDMaker/TreeMaker.h"

void TreeMaker::SetEventInfo()
{

  aTree->Branch("runNumber",       &runNumber,       "runNumber/I"      );
  aTree->Branch("eventNumber",     &eventNumber,     "eventNumber/I"    ); 
  aTree->Branch("LumiBlock",       &LumiBlock,       "LumiBlock/I"      ); 
  aTree->Branch("TimeStampOffset", &TimeStampOffset, "TimeStampOffset/I"); 
  aTree->Branch("TimeStamp",       &TimeStamp,       "TimeStamp/I"      ); 
  aTree->Branch("BunchCrossingID", &BunchCrossingID, "BunchCrossingID/I"); 
  aTree->Branch("DetectorMask0",   &DetectorMask0,   "DetectorMask0/I"  );
  aTree->Branch("DetectorMask1",   &DetectorMask1,   "DetectorMask1/I"  );
  
  aTree->Branch("IsSimulation",  &IsSimulation,  "IsSimulation/I" );
  aTree->Branch("IsCalibration", &IsCalibration, "IsCalibration/I");
  aTree->Branch("IsTestBeam",    &IsTestBeam,    "IsTestBeam/I"   );
  
  aTree->Branch("eventWeight",        &eventWeight,        "eventWeight/D"       );
  aTree->Branch("eventWeightMCatNLO", &eventWeightMCatNLO, "eventWeightMCatNLO/D");
      
}

void TreeMaker::ClearEventInfo()
{

  if(!aEventInfo) return;

  runNumber          = -1;
  eventNumber        = -1;
  LumiBlock          = -1;
  TimeStampOffset    = -1;
  TimeStamp          = -1;
  BunchCrossingID    = -1;
  DetectorMask0      = -1;
  DetectorMask1      = -1;
  
  IsSimulation       = -1;
  IsCalibration      = -1;
  IsTestBeam         = -1;
  
  eventWeight        = -1;
  eventWeightMCatNLO = -1;
  
}

void TreeMaker::FillEventInfo()
{

  if(!aEventInfo) return;

  EventID * aEventID = aEventInfo->event_ID();
    
  runNumber       = aEventID->run_number();
  eventNumber     = aEventID->event_number();
  LumiBlock       = aEventID->lumi_block();
  TimeStampOffset = aEventID->time_stamp_ns_offset();
  TimeStamp       = aEventID->time_stamp();
  BunchCrossingID = aEventID->bunch_crossing_id();
  DetectorMask0   = aEventID->detector_mask0();
  DetectorMask1   = aEventID->detector_mask1();
  
  EventType * aEventType = aEventInfo->event_type();
  
  bool Simulation  = aEventType->test(EventType::IS_SIMULATION );
  bool Calibration = aEventType->test(EventType::IS_CALIBRATION);
  bool TestBeam    = aEventType->test(EventType::IS_TESTBEAM   );
  
  if(Simulation)  IsSimulation  = 1;
  else            IsSimulation  = 0;
  
  if(Calibration) IsCalibration = 1;
  else            IsCalibration = 0;
  
  if(TestBeam)    IsTestBeam    = 1;
  else            IsTestBeam    = 0;
  
  eventWeight = aEventType->mc_event_weight();
  
  eventWeightMCatNLO = 1.;
  
  if(aMcEventContainer)
  {
    
    const HepMC::GenEvent * aGenEvent             = (*aMcEventContainer)[0];
    const HepMC::WeightContainer& weightContainer = aGenEvent->weights();
    
    unsigned int Size = weightContainer.size();
    if(Size > 0) eventWeightMCatNLO = weightContainer[0];
/*    
    if(Size == 1)      eventWeightMCatNLO = weightContainer[0];
    else if(Size >= 2) eventWeightMCatNLO = weightContainer[1];
*/
  }
  
}
