#include "SingleTopDPDMaker/GlobalVariables.h"

double GlobalVariables::PtSum(INavigable4MomentumCollection * aParticleContainer)
{
  
  double PtSum = 0;
  
  INavigable4MomentumCollection::const_iterator Itr;
      
  for(Itr=aParticleContainer->begin(); Itr!=aParticleContainer->end(); Itr++)
  {
    PtSum += (*Itr)->pt();
  }
  
  return PtSum;
  
}

double GlobalVariables::PzSum(INavigable4MomentumCollection * aParticleContainer)
{
  
  double PzSum = 0;
  
  INavigable4MomentumCollection::const_iterator Itr;
      
  for(Itr=aParticleContainer->begin(); Itr!=aParticleContainer->end(); Itr++)
  {
    PzSum += (*Itr)->pz();
  }
  
  return PzSum;
  
}

double GlobalVariables::Shat(INavigable4MomentumCollection * aParticleContainer)
{
    
  double Shat = 0;
  
  INavigable4MomentumCollection::const_iterator Itr;
      
  for(Itr=aParticleContainer->begin(); Itr!=aParticleContainer->end(); Itr++)
  {
    Shat += (*Itr)->pt()*(*Itr)->pt()+(*Itr)->e()*(*Itr)->e();
  }
  
  if(Shat > 0) Shat = sqrt(Shat); 
  
  return Shat;
  
}

double GlobalVariables::InvariantMass(INavigable4MomentumCollection * aParticleContainer)
{
  
  HepLorentzVector hlvSum = 0;
  
  INavigable4MomentumCollection::const_iterator Itr;
      
  for(Itr=aParticleContainer->begin(); Itr!=aParticleContainer->end(); Itr++)
  {
    hlvSum += (*Itr)->hlv();
  }
    
  double Mass = hlvSum.m();
  
  return Mass;
  
}   
    
std::map<std::string, double> GlobalVariables::TopologicalVariables(INavigable4MomentumCollection * aParticleContainer)
{

  TMatrixD MomentumTensor(3,3);

  double P2Sum = 0;
  double PtSum = 0;
  double ESum  = 0;
  
  INavigable4MomentumCollection::const_iterator Itr;
      
  for(Itr=aParticleContainer->begin(); Itr!=aParticleContainer->end(); Itr++)
  {
    
    MomentumTensor(0,0) += (*Itr)->px()*(*Itr)->px();
    MomentumTensor(0,1) += (*Itr)->px()*(*Itr)->py();
    MomentumTensor(0,2) += (*Itr)->px()*(*Itr)->pz();
    MomentumTensor(1,0) += (*Itr)->py()*(*Itr)->px();
    MomentumTensor(1,1) += (*Itr)->py()*(*Itr)->py();
    MomentumTensor(2,2) += (*Itr)->py()*(*Itr)->pz();
    MomentumTensor(2,0) += (*Itr)->pz()*(*Itr)->px();
    MomentumTensor(2,1) += (*Itr)->pz()*(*Itr)->py();
    MomentumTensor(2,2) += (*Itr)->pz()*(*Itr)->pz();
    
    P2Sum += (*Itr)->p()*(*Itr)->p();
    PtSum += (*Itr)->pt();
    ESum  += (*Itr)->e();
    
  }
      
  double Aplanarity = -1;
  double Sphericity = -1;
  double Centrality = -1;
  
  if(ESum > 0) Centrality = PtSum/ESum;   

  if(P2Sum > 0)
  {
  
    for(int i=0; i<3; i++)
      for(int j=0; j<3; j++) MomentumTensor(i,j) /= P2Sum;
        
    TDecompSVD * aSVD = new TDecompSVD(MomentumTensor);
    
    TVectorD E = aSVD->GetSig();
    
    delete aSVD;
        
    Aplanarity = 1.5*E[2];
    Sphericity = 1.5*(E[1]+E[2]);
  
  }

  std::map<std::string, double> Variables;
  
  Variables["Aplanarity"] = Aplanarity;
  Variables["Sphericity"] = Sphericity;
  Variables["Centrality"] = Centrality;
    
  return Variables;  
  
}

