#include "SingleTopDPDMaker/JetSlimming.h"

JetSlimming::JetSlimming(const std::string& name, ISvcLocator* pSvcLocator) : Algorithm(name, pSvcLocator)
{

  declareProperty("JetContainerName", JetContainerName);
          
}

JetSlimming::~JetSlimming(){}

StatusCode JetSlimming::initialize()
{
  
  MsgStream MsgLog(msgSvc(), name());
  
  MsgLog << MSG::INFO << "Initializing " << name() << endreq;
      
  MsgLog << MSG::INFO << "Jet Container Name = " << JetContainerName << endreq;
         
  StatusCode status = service("StoreGateSvc", aStoreGateSvc);

  if(status.isFailure()) 
  {
    MsgLog << MSG::FATAL << "StoreGateSvc Unavailable" << endreq;
    return StatusCode::FAILURE;
  }
            
  InputEventNumber  = 0;
  OutputEventNumber = 0;
  
  return StatusCode::SUCCESS;
  
}

StatusCode JetSlimming::finalize()
{

  MsgStream MsgLog(msgSvc(), name());
  
  MsgLog << MSG::INFO << "Finalizing " << name() << endreq;
  
  MsgLog << MSG::INFO << "Input  Event Number = " << InputEventNumber  << endreq;
  MsgLog << MSG::INFO << "Output Event Number = " << OutputEventNumber << endreq;
          
  return StatusCode::SUCCESS;
  
}

StatusCode JetSlimming::execute()
{

  MsgStream MsgLog(msgSvc(), name());
    
  InputEventNumber++;
    
  for(unsigned int i=0; i<JetContainerName.size(); i++)
  {
  
    const JetCollection * aJetContainer;
    StatusCode status = aStoreGateSvc->retrieve(aJetContainer, JetContainerName[i]);
  
    if(status.isFailure())
    {
      MsgLog << MSG::FATAL << JetContainerName[i] << " Unavailable" << endreq;
      return StatusCode::FAILURE;
    }
    
    this->Slim(aJetContainer);
    
  }
  
  setFilterPassed(true);
          
  OutputEventNumber++;
  
  return StatusCode::SUCCESS;
  
}

void JetSlimming::Slim(const JetCollection* aJetContainer)
{

  JetCollection::const_iterator Itr;
  
  for(Itr=aJetContainer->begin(); Itr!=aJetContainer->end(); Itr++)
  {
    
    Jet * aJet = *Itr;
    aJet->removeAssociation("Tracks");
        
  }
  
}
