#include "SingleTopDPDMaker/TreeMaker.h"

void TreeMaker::SetJets()
{

  std::vector<std::string>::const_iterator Itr;
  
  for(Itr=JetContainerLabel.begin(); Itr!=JetContainerLabel.end(); Itr++)
  {
  
    std::string Label = *Itr;

    Jet_pdgId[Label]  = new std::vector<double>;
    Jet_m[Label]      = new std::vector<double>;
    Jet_charge[Label] = new std::vector<double>;
    Jet_E[Label]      = new std::vector<double>;
    Jet_p_T[Label]    = new std::vector<double>;
    Jet_phi[Label]    = new std::vector<double>;
    Jet_eta[Label]    = new std::vector<double>;
    Jet_px[Label]     = new std::vector<double>;
    Jet_py[Label]     = new std::vector<double>;
    Jet_pz[Label]     = new std::vector<double>;
  
    Jet_nTracks[Label] = new std::vector<int>;
  
    Jet_IP1D[Label]        = new std::vector<double>;
    Jet_IP2D[Label]        = new std::vector<double>;
    Jet_IP3D[Label]        = new std::vector<double>;
    Jet_SV1[Label]         = new std::vector<double>;
    Jet_SV2[Label]         = new std::vector<double>;
    Jet_SecVtxTagBU[Label] = new std::vector<double>;
    Jet_weight[Label]      = new std::vector<double>;
    
    Jet_SoftElectronWeight[Label]   = new std::vector<double>;
    Jet_SoftElectronNumTrack[Label] = new std::vector<int>;
    Jet_SoftMuonWeight[Label]       = new std::vector<double>;
    Jet_SoftMuonNumTrack[Label]     = new std::vector<int>;
    
    std::string N  = Label+"_"+"N";
    std::string NI = N+"/I";
      
    aTree->Branch(N.c_str(), &Jet_N[Label] , NI.c_str());
    
    std::string pdgId  = Label+"_"+"pdgId";
    std::string m      = Label+"_"+"m";
    std::string charge = Label+"_"+"charge";
    std::string E      = Label+"_"+"E";
    std::string p_T    = Label+"_"+"p_T";
    std::string phi    = Label+"_"+"phi";
    std::string eta    = Label+"_"+"eta";
    std::string px     = Label+"_"+"px";
    std::string py     = Label+"_"+"py";
    std::string pz     = Label+"_"+"pz";
  
    aTree->Branch(pdgId.c_str(),  &Jet_pdgId[Label] );
    aTree->Branch(m.c_str(),      &Jet_m[Label]     );
    aTree->Branch(charge.c_str(), &Jet_charge[Label]);
    aTree->Branch(E.c_str(),      &Jet_E[Label]     );
    aTree->Branch(p_T.c_str(),    &Jet_p_T[Label]   );
    aTree->Branch(phi.c_str(),    &Jet_phi[Label]   );
    aTree->Branch(eta.c_str(),    &Jet_eta[Label]   );
    aTree->Branch(px.c_str(),     &Jet_px[Label]    );
    aTree->Branch(py.c_str(),     &Jet_py[Label]    );
    aTree->Branch(pz.c_str(),     &Jet_pz[Label]    );
    
    std::string nTracks = Label+"_"+"nTracks";
  
    aTree->Branch(nTracks.c_str(), &Jet_nTracks[Label]); 
    
    std::string IP1D        = Label+"_"+"IP1D";
    std::string IP2D        = Label+"_"+"IP2D";
    std::string IP3D        = Label+"_"+"IP3D";
    std::string SV1         = Label+"_"+"SV1";
    std::string SV2         = Label+"_"+"SV2";
    std::string SecVtxTagBU = Label+"_"+"SecVtxTagBU";
    std::string weight      = Label+"_"+"weight";
   
    aTree->Branch(IP1D.c_str(),        &Jet_IP1D[Label]       );
    aTree->Branch(IP2D.c_str(),        &Jet_IP2D[Label]       );
    aTree->Branch(IP3D.c_str(),        &Jet_IP3D[Label]       );
    aTree->Branch(SV1.c_str(),         &Jet_SV1[Label]        );
    aTree->Branch(SV2.c_str(),         &Jet_SV2[Label]        );
    aTree->Branch(SecVtxTagBU.c_str(), &Jet_SecVtxTagBU[Label]);
    aTree->Branch(weight.c_str(),      &Jet_weight[Label]     );
    
    std::string SoftElectronWeight   = Label+"_"+"SoftElectronWeight";
    std::string SoftElectronNumTrack = Label+"_"+"SoftElectronNumTrack";
    std::string SoftMuonWeight       = Label+"_"+"SoftMuonWeight";
    std::string SoftMuonNumTrack     = Label+"_"+"SoftMuonNumTrack";
    
    aTree->Branch(SoftElectronWeight.c_str(),   &Jet_SoftElectronWeight[Label]  );
    aTree->Branch(SoftElectronNumTrack.c_str(), &Jet_SoftElectronNumTrack[Label]);
    aTree->Branch(SoftMuonWeight.c_str(),       &Jet_SoftMuonWeight[Label]      );
    aTree->Branch(SoftMuonNumTrack.c_str(),     &Jet_SoftMuonNumTrack[Label]    );
    
  }
    
}

void TreeMaker::DeleteJets()
{

  std::vector<std::string>::const_iterator Itr;
  
  for(Itr=JetContainerLabel.begin(); Itr!=JetContainerLabel.end(); Itr++)
  {
  
    std::string Label = *Itr;
  
    delete Jet_pdgId[Label];
    delete Jet_m[Label];
    delete Jet_charge[Label];
    delete Jet_E[Label];
    delete Jet_p_T[Label];
    delete Jet_phi[Label];
    delete Jet_eta[Label];
    delete Jet_px[Label];
    delete Jet_py[Label];
    delete Jet_pz[Label];
  
    delete Jet_nTracks[Label];
  
    delete Jet_IP1D[Label];
    delete Jet_IP2D[Label];
    delete Jet_IP3D[Label];
    delete Jet_SV1[Label];
    delete Jet_SV2[Label];
    delete Jet_SecVtxTagBU[Label];
    delete Jet_weight[Label];
    
    delete Jet_SoftElectronWeight[Label];
    delete Jet_SoftElectronNumTrack[Label];
    delete Jet_SoftMuonWeight[Label];
    delete Jet_SoftMuonNumTrack[Label];
    
  }
    
}

void TreeMaker::ClearJets()
{

  std::vector<std::string>::const_iterator Itr;
  
  for(Itr=JetContainerLabel.begin(); Itr!=JetContainerLabel.end(); Itr++)
  {
  
    std::string Label = *Itr;

    Jet_N[Label] = 0;
  
    Jet_pdgId[Label]->clear();
    Jet_m[Label]->clear();
    Jet_charge[Label]->clear();
    Jet_E[Label]->clear();
    Jet_p_T[Label]->clear();
    Jet_phi[Label]->clear();
    Jet_eta[Label]->clear();
    Jet_px[Label]->clear();
    Jet_py[Label]->clear();
    Jet_pz[Label]->clear();
  
    Jet_nTracks[Label]->clear();
  
    Jet_IP1D[Label]->clear();
    Jet_IP2D[Label]->clear();
    Jet_IP3D[Label]->clear();
    Jet_SV1[Label]->clear();
    Jet_SV2[Label]->clear();
    Jet_SecVtxTagBU[Label]->clear();
    Jet_weight[Label]->clear();
    
    Jet_SoftElectronWeight[Label]->clear();
    Jet_SoftElectronNumTrack[Label]->clear();
    Jet_SoftMuonWeight[Label]->clear();
    Jet_SoftMuonNumTrack[Label]->clear();
  
  }
  
}

void TreeMaker::FillJets()
{

  std::vector<std::string>::const_iterator Itr;
  
  for(Itr=JetContainerLabel.begin(); Itr!=JetContainerLabel.end(); Itr++)
  {
  
    std::string Label = *Itr;
  
    JetCollection::const_iterator cItr;
  
    for(cItr=aJetContainer[Label]->begin(); cItr!=aJetContainer[Label]->end(); cItr++)
    {
    
      const Jet * aJet = *cItr;
      
      if(aJet->pt() <= JetPtCut[Label]) continue;
               
      Jet_pdgId[Label]->push_back( aJet->pdgId()  );
      Jet_m[Label]->push_back(     aJet->m()      );
      Jet_charge[Label]->push_back(aJet->charge() );
      Jet_E[Label]->push_back(     aJet->e()/GeV  );
      Jet_p_T[Label]->push_back(   aJet->pt()/GeV );
      Jet_phi[Label]->push_back(   aJet->phi()    );
      Jet_eta[Label]->push_back(   aJet->eta()    );
      Jet_px[Label]->push_back(    aJet->px()/GeV );
      Jet_py[Label]->push_back(    aJet->py()/GeV );
      Jet_pz[Label]->push_back(    aJet->pz()/GeV );
    
      const Analysis::TrackAssociation * aTrackAssociation = aJet->getAssociation<Analysis::TrackAssociation>("Tracks", true);
    
      if(aTrackAssociation) Jet_nTracks[Label]->push_back(aTrackAssociation->nTracks());
      else                  Jet_nTracks[Label]->push_back(-1);
    
      Jet_IP1D[Label]->push_back(       aJet->getFlavourTagWeight("IP1D")       );
      Jet_IP2D[Label]->push_back(       aJet->getFlavourTagWeight("IP2D")       );
      Jet_IP3D[Label]->push_back(       aJet->getFlavourTagWeight("IP3D")       );
      Jet_SV1[Label]->push_back(        aJet->getFlavourTagWeight("SV1")        );
      Jet_SV2[Label]->push_back(        aJet->getFlavourTagWeight("SV2")        );
      Jet_SecVtxTagBU[Label]->push_back(aJet->getFlavourTagWeight("SecVtxTagBU"));
      Jet_weight[Label]->push_back(     aJet->getFlavourTagWeight()             );
            
      Jet_SoftElectronWeight[Label]->push_back(aJet->getFlavourTagWeight("SoftElectronTag"));
      Jet_SoftMuonWeight[Label]->push_back(    aJet->getFlavourTagWeight("SoftMuonTag")    );
    
      const Analysis::SoftElectronInfo * aSoftElectronInfo = static_cast<const Analysis::SoftElectronInfo*>(aJet->tagInfo("SoftElectronTag"));
      const Analysis::SoftMuonInfo     * aSoftMuonInfo     = static_cast<const Analysis::SoftMuonInfo*>    (aJet->tagInfo("SoftMuonTag")    );
    
      if(aSoftElectronInfo) Jet_SoftElectronNumTrack[Label]->push_back(aSoftElectronInfo->numTrackInfo());
      else                  Jet_SoftElectronNumTrack[Label]->push_back(-1);
            
      if(aSoftMuonInfo)     Jet_SoftMuonNumTrack[Label]->push_back(aSoftMuonInfo->numTrackInfo());
      else                  Jet_SoftMuonNumTrack[Label]->push_back(-1);
        
    }
    
    Jet_N[Label] = Jet_E[Label]->size();
    
  }

}
