#include "SingleTopDPDMaker/TreeMaker.h"

void TreeMaker::SetPhotons()
{

  std::vector<std::string>::const_iterator Itr;
  
  for(Itr=PhotonContainerLabel.begin(); Itr!=PhotonContainerLabel.end(); Itr++)
  {
  
    std::string Label = *Itr;

    Photon_pdgId[Label]  = new std::vector<double>;
    Photon_m[Label]      = new std::vector<double>;
    Photon_charge[Label] = new std::vector<double>;
    Photon_E[Label]      = new std::vector<double>;
    Photon_p_T[Label]    = new std::vector<double>;
    Photon_phi[Label]    = new std::vector<double>;
    Photon_eta[Label]    = new std::vector<double>;
    Photon_px[Label]     = new std::vector<double>;
    Photon_py[Label]     = new std::vector<double>;
    Photon_pz[Label]     = new std::vector<double>;
  
    Photon_IsEM[Label]                = new std::vector<double>;
    Photon_author[Label]              = new std::vector<int>;
    Photon_ElectronWeight[Label]      = new std::vector<double>;
    Photon_BgWeight[Label]            = new std::vector<double>;
    Photon_NeuralNet[Label]           = new std::vector<double>;
    Photon_Hmatrix[Label]             = new std::vector<double>;
    Photon_Hmatrix5[Label]            = new std::vector<double>;
    Photon_SofteIsEM[Label]           = new std::vector<double>;
    Photon_SofteBgWeight[Label]       = new std::vector<double>;
    Photon_SofteNeuralNet[Label]      = new std::vector<double>;
    Photon_IsolationLikelihood[Label] = new std::vector<double>;
    Photon_AdaBoost[Label]            = new std::vector<double>;
    Photon_LastEgammaPID[Label]       = new std::vector<double>;
  
    Photon_etcone20[Label] = new std::vector<double>;
    
    std::string N  = Label+"_"+"N";
    std::string NI = N+"/I";
        
    aTree->Branch(N.c_str(), &Photon_N[Label], NI.c_str());
    
    std::string pdgId  = Label+"_"+"pdgId";
    std::string m      = Label+"_"+"m";
    std::string charge = Label+"_"+"charge";
    std::string E      = Label+"_"+"E";
    std::string p_T    = Label+"_"+"p_T";
    std::string phi    = Label+"_"+"phi";
    std::string eta    = Label+"_"+"eta";
    std::string px     = Label+"_"+"px";
    std::string py     = Label+"_"+"py";
    std::string pz     = Label+"_"+"pz";
  
    aTree->Branch(pdgId.c_str(),  &Photon_pdgId[Label] );
    aTree->Branch(m.c_str(),      &Photon_m[Label]     );
    aTree->Branch(charge.c_str(), &Photon_charge[Label]);
    aTree->Branch(E.c_str(),      &Photon_E[Label]     );
    aTree->Branch(p_T.c_str(),    &Photon_p_T[Label]   );
    aTree->Branch(phi.c_str(),    &Photon_phi[Label]   );
    aTree->Branch(eta.c_str(),    &Photon_eta[Label]   );
    aTree->Branch(px.c_str(),     &Photon_px[Label]    );
    aTree->Branch(py.c_str(),     &Photon_py[Label]    );
    aTree->Branch(pz.c_str(),     &Photon_pz[Label]    );
    
    std::string IsEM                = Label+"_"+"IsEM";
    std::string author              = Label+"_"+"author";
    std::string ElectronWeight      = Label+"_"+"ElectronWeight";
    std::string BgWeight            = Label+"_"+"BgWeight";
    std::string NeuralNet           = Label+"_"+"NeuralNet";
    std::string Hmatrix             = Label+"_"+"Hmatrix";
    std::string Hmatrix5            = Label+"_"+"Hmatrix5";
    std::string SofteIsEM           = Label+"_"+"SofteIsEM";
    std::string SofteBgWeight       = Label+"_"+"SofteBgWeight";
    std::string SofteNeuralNet      = Label+"_"+"SofteNeuralNet";
    std::string IsolationLikelihood = Label+"_"+"IsolationLikelihood";
    std::string AdaBoost            = Label+"_"+"AdaBoost";
    std::string LastEgammaPID       = Label+"_"+"LastEgammaPID";
  
    aTree->Branch(IsEM.c_str(),                &Photon_IsEM[Label]               );
    aTree->Branch(author.c_str(),              &Photon_author[Label]             );
    aTree->Branch(ElectronWeight.c_str(),      &Photon_ElectronWeight[Label]     );
    aTree->Branch(BgWeight.c_str(),            &Photon_BgWeight[Label]           );
    aTree->Branch(NeuralNet.c_str(),           &Photon_NeuralNet[Label]          );
    aTree->Branch(Hmatrix.c_str(),             &Photon_Hmatrix[Label]            );
    aTree->Branch(Hmatrix5.c_str(),            &Photon_Hmatrix5[Label]           );
    aTree->Branch(SofteIsEM.c_str(),           &Photon_SofteIsEM[Label]          );
    aTree->Branch(SofteBgWeight.c_str(),       &Photon_SofteBgWeight[Label]      );
    aTree->Branch(SofteNeuralNet.c_str(),      &Photon_SofteNeuralNet[Label]     );
    aTree->Branch(IsolationLikelihood.c_str(), &Photon_IsolationLikelihood[Label]);
    aTree->Branch(AdaBoost.c_str(),            &Photon_AdaBoost[Label]           );
    aTree->Branch(LastEgammaPID.c_str(),       &Photon_LastEgammaPID[Label]      );
    
    std::string etcone20 = Label+"_"+"etcone20";
    
    aTree->Branch(etcone20.c_str(), &Photon_etcone20[Label]);
    
  }
      
}

void TreeMaker::DeletePhotons()
{

  std::vector<std::string>::const_iterator Itr;
  
  for(Itr=PhotonContainerLabel.begin(); Itr!=PhotonContainerLabel.end(); Itr++)
  {
  
    std::string Label = *Itr;

    delete Photon_pdgId[Label];
    delete Photon_m[Label];
    delete Photon_charge[Label];
    delete Photon_E[Label];
    delete Photon_p_T[Label];
    delete Photon_phi[Label];
    delete Photon_eta[Label];
    delete Photon_px[Label];
    delete Photon_py[Label];
    delete Photon_pz[Label];
  
    delete Photon_IsEM[Label];
    delete Photon_author[Label];
    delete Photon_ElectronWeight[Label];
    delete Photon_BgWeight[Label];
    delete Photon_NeuralNet[Label];
    delete Photon_Hmatrix[Label];
    delete Photon_Hmatrix5[Label];
    delete Photon_SofteIsEM[Label];
    delete Photon_SofteBgWeight[Label];
    delete Photon_SofteNeuralNet[Label];
    delete Photon_IsolationLikelihood[Label];
    delete Photon_AdaBoost[Label];
    delete Photon_LastEgammaPID[Label];
    
    delete Photon_etcone20[Label];
    
  }
        
}

void TreeMaker::ClearPhotons()
{

  std::vector<std::string>::const_iterator Itr;
  
  for(Itr=PhotonContainerLabel.begin(); Itr!=PhotonContainerLabel.end(); Itr++)
  {
  
    std::string Label = *Itr;

    Photon_N[Label] = 0;

    Photon_pdgId[Label]->clear();
    Photon_m[Label]->clear();
    Photon_charge[Label]->clear();
    Photon_E[Label]->clear();
    Photon_p_T[Label]->clear();
    Photon_phi[Label]->clear();
    Photon_eta[Label]->clear();
    Photon_px[Label]->clear();
    Photon_py[Label]->clear();
    Photon_pz[Label]->clear();
  
    Photon_IsEM[Label]->clear();
    Photon_author[Label]->clear();
    Photon_ElectronWeight[Label]->clear();
    Photon_BgWeight[Label]->clear();
    Photon_NeuralNet[Label]->clear();
    Photon_Hmatrix[Label]->clear();
    Photon_Hmatrix5[Label]->clear();
    Photon_SofteIsEM[Label]->clear();
    Photon_SofteBgWeight[Label]->clear();
    Photon_SofteNeuralNet[Label]->clear();
    Photon_IsolationLikelihood[Label]->clear();
    Photon_AdaBoost[Label]->clear();
    Photon_LastEgammaPID[Label]->clear();
    
    Photon_etcone20[Label]->clear();
    
  }
  
}

void TreeMaker::FillPhotons()
{

  std::vector<std::string>::const_iterator Itr;
  
  for(Itr=PhotonContainerLabel.begin(); Itr!=PhotonContainerLabel.end(); Itr++)
  {
  
    std::string Label = *Itr;

    PhotonContainer::const_iterator cItr;
  
    for(cItr=aPhotonContainer[Label]->begin(); cItr!=aPhotonContainer[Label]->end(); cItr++)
    {
    
      const Analysis::Photon * aPhoton = *cItr;
      
      if(aPhoton->pt() <= PhotonPtCut[Label]) continue;
                       
      Photon_pdgId[Label]->push_back( aPhoton->pdgId()  );
      Photon_m[Label]->push_back(     aPhoton->m()      );
      Photon_charge[Label]->push_back(aPhoton->charge() );
      Photon_E[Label]->push_back(     aPhoton->e()/GeV  );
      Photon_p_T[Label]->push_back(   aPhoton->pt()/GeV );
      Photon_phi[Label]->push_back(   aPhoton->phi()    );
      Photon_eta[Label]->push_back(   aPhoton->eta()    );
      Photon_px[Label]->push_back(    aPhoton->px()/GeV );
      Photon_py[Label]->push_back(    aPhoton->py()/GeV );
      Photon_pz[Label]->push_back(    aPhoton->pz()/GeV );
    
      int IsEM      = static_cast<int>(aPhoton->egammaID(egammaPID::IsEM)     );
      int SofteIsEM = static_cast<int>(aPhoton->egammaID(egammaPID::SofteIsEM));
    
      Photon_IsEM[Label]->push_back(               IsEM                                             );
      Photon_author[Label]->push_back(             aPhoton->author()                                );
      Photon_ElectronWeight[Label]->push_back(     aPhoton->egammaID(egammaPID::ElectronWeight)     );
      Photon_BgWeight[Label]->push_back(           aPhoton->egammaID(egammaPID::BgWeight)           );
      Photon_NeuralNet[Label]->push_back(          aPhoton->egammaID(egammaPID::NeuralNet)          );
      Photon_Hmatrix[Label]->push_back(            aPhoton->egammaID(egammaPID::Hmatrix)            );
      Photon_Hmatrix5[Label]->push_back(           aPhoton->egammaID(egammaPID::Hmatrix5)           );
      Photon_SofteIsEM[Label]->push_back(          SofteIsEM                                        );
      Photon_SofteBgWeight[Label]->push_back(      aPhoton->egammaID(egammaPID::SofteBgWeight)      );
      Photon_SofteNeuralNet[Label]->push_back(     aPhoton->egammaID(egammaPID::SofteNeuralNet)     );
      Photon_IsolationLikelihood[Label]->push_back(aPhoton->egammaID(egammaPID::IsolationLikelihood));
      Photon_AdaBoost[Label]->push_back(           aPhoton->egammaID(egammaPID::AdaBoost)           );
      Photon_LastEgammaPID[Label]->push_back(      aPhoton->egammaID(egammaPID::LastEgammaPID)      );
        
      const EMShower * aEMShower = aPhoton->detail<EMShower>("egDetailAOD");
    
      if(aEMShower) Photon_etcone20[Label]->push_back(aEMShower->parameter(egammaParameters::etcone20)/GeV);
      else          Photon_etcone20[Label]->push_back(-1);
    
    }
    
    Photon_N[Label] = Photon_E[Label]->size();
    
  }

}
