#include "SingleTopDPDMaker/TrackSlimming.h"

TrackSlimming::TrackSlimming(const std::string& name, ISvcLocator* pSvcLocator) : Algorithm(name, pSvcLocator)
{

  declareProperty("TrackParticleContainerName", TrackParticleContainerName = "TrackParticleCandidate");
  declareProperty("TrackPtCut",                 TrackPtCut                 = 5.0*GeV                 );
          
}

TrackSlimming::~TrackSlimming(){}

StatusCode TrackSlimming::initialize()
{
  
  MsgStream MsgLog(msgSvc(), name());
  
  MsgLog << MSG::INFO << "Initializing " << name() << endreq;
      
  MsgLog << MSG::INFO << "Track Particle Container Name = " << TrackParticleContainerName << endreq;
  MsgLog << MSG::INFO << "TrackPtCut = " << TrackPtCut/GeV << " GeV"   << endreq;
         
  StatusCode status = service("StoreGateSvc", aStoreGateSvc);

  if(status.isFailure()) 
  {
    MsgLog << MSG::FATAL << "StoreGateSvc Unavailable" << endreq;
    return StatusCode::FAILURE;
  }
            
  InputEventNumber  = 0;
  OutputEventNumber = 0;
  
  return StatusCode::SUCCESS;
  
}

StatusCode TrackSlimming::finalize()
{

  MsgStream MsgLog(msgSvc(), name());
  
  MsgLog << MSG::INFO << "Finalizing " << name() << endreq;
  
  MsgLog << MSG::INFO << "Input  Event Number = " << InputEventNumber  << endreq;
  MsgLog << MSG::INFO << "Output Event Number = " << OutputEventNumber << endreq;
          
  return StatusCode::SUCCESS;
  
}

StatusCode TrackSlimming::execute()
{

  MsgStream MsgLog(msgSvc(), name());
    
  InputEventNumber++;
    
  const Rec::TrackParticleContainer * aTrackParticleContainer;
  StatusCode status = aStoreGateSvc->retrieve(aTrackParticleContainer, TrackParticleContainerName);
  
  if(status.isFailure())
  {
    MsgLog << MSG::FATAL << "Track Particle Container Unavailable" << endreq;
    return StatusCode::FAILURE;
  }
    
  this->Slim(aTrackParticleContainer);
  
  setFilterPassed(true);
              
  OutputEventNumber++;
  
  return StatusCode::SUCCESS;
  
}

void TrackSlimming::Slim(const Rec::TrackParticleContainer * aTrackParticleContainer)
{

  Rec::TrackParticleContainer::const_iterator Itr;
  
  for(Itr=aTrackParticleContainer->begin(); Itr!=aTrackParticleContainer->end(); Itr++)
  {
    
    Rec::TrackParticle * aTrackParticle = *Itr;
            
    if(aTrackParticle->pt() < TrackPtCut)
    {
      aTrackParticle->removeSummary();
      aTrackParticle->removeErrorMatrix();
    }
        
  }
  
}
