#include "SingleTopDPDMaker/TriggerSlimming.h"

TriggerSlimming::TriggerSlimming(const std::string& name, ISvcLocator* pSvcLocator) : Algorithm(name, pSvcLocator), 
aTriggerDecisionTool("TrigDec::TrigDecisionTool")
{
 
  declareProperty("TriggerDecisionTool", aTriggerDecisionTool);

}

TriggerSlimming::~TriggerSlimming(){}

StatusCode TriggerSlimming::initialize()
{

  MsgStream MsgLog(msgSvc(), name());
  
  MsgLog << MSG::INFO << "Initializing " << name() << endreq;

  StatusCode status = aTriggerDecisionTool.retrieve();
  
  if(status.isFailure())
  {
    MsgLog << MSG::FATAL << "Trigger Decision Tool Unavailable" << endreq;
    return StatusCode::FAILURE;
  }
  
  InputEventNumber  = 0;
  OutputEventNumber = 0;
  
  return StatusCode::SUCCESS;

}

StatusCode TriggerSlimming::finalize()
{

  MsgStream MsgLog(msgSvc(), name());
  
  MsgLog << MSG::INFO << "Finalizing " << name() << endreq;
  
  MsgLog << MSG::INFO << "Input  Event Number = " << InputEventNumber  << endreq;
  MsgLog << MSG::INFO << "Output Event Number = " << OutputEventNumber << endreq;
      
  return StatusCode::SUCCESS;

}

StatusCode TriggerSlimming::execute()
{

  MsgStream MsgLog(msgSvc(), name());

  InputEventNumber++;
              
  bool TestL2 = aTriggerDecisionTool->removeNavigation(TrigDec::L2);
  
  if(!TestL2) MsgLog << MSG::INFO << "L2 Navigation Removal Error" << endreq;
  
  bool TestEF = aTriggerDecisionTool->removeNavigation(TrigDec::EF);
  
  if(!TestEF) MsgLog << MSG::INFO << "EF Navigation Removal Error" << endreq;
             
  setFilterPassed(true);
  
  OutputEventNumber++;
      
  return StatusCode::SUCCESS;

}

