#include "SingleTopDPDMaker/TriggerTreeMaker.h"

TriggerTreeMaker::TriggerTreeMaker(const std::string& name, ISvcLocator* pSvcLocator) : Algorithm(name, pSvcLocator)
{

  declareProperty("TreeName",                 TreeName                 = "Trigger"             );
  
  declareProperty("TriggerDecisionInfoName",  TriggerDecisionInfoName  = "TriggerDecisionInfo" );
  declareProperty("TriggerDecisionInfoLabel", TriggerDecisionInfoLabel = "Passed"              );
          
}

TriggerTreeMaker::~TriggerTreeMaker(){}

StatusCode TriggerTreeMaker::initialize()
{
  
  MsgStream MsgLog(messageService(), name());
  
  MsgLog << MSG::INFO << "Initializing " << name() << endreq;
  
  MsgLog << MSG::INFO << "Tree Name = " << TreeName << endreq;
  
  MsgLog << MSG::INFO << "Trigger Decision Info Name  = " << TriggerDecisionInfoName  << endreq;
  MsgLog << MSG::INFO << "Trigger Decision Info Label = " << TriggerDecisionInfoLabel << endreq;
            
  StatusCode status;
  
  status = service("StoreGateSvc", aStoreGateSvc);

  if(status.isFailure()) 
  {
    MsgLog << MSG::FATAL << "StoreGateSvc Unavailable" << endreq;
    return StatusCode::FAILURE;
  }
  
  status = service("THistSvc", aTHistSvc);

  if(status.isFailure()) 
  {
    MsgLog << MSG::FATAL << "THistSvc Unavailable" << endreq;
    return StatusCode::FAILURE;
  }
  
  std::string TreeTitle = TreeName;
  aTree = new TTree(TreeName.c_str(), TreeTitle.c_str());
  
  std::string FullTreeName = "/AANT/"+TreeName;
  status = aTHistSvc->regTree(FullTreeName, aTree);

  if(status.isFailure()) 
  {
    MsgLog << MSG::FATAL << "regTree Unavailable" << endreq;
    return StatusCode::FAILURE;
  }
      
  this->SetBranches(); 
  
  InputEventNumber  = 0;
  OutputEventNumber = 0;
        
  return StatusCode::SUCCESS;
  
}

StatusCode TriggerTreeMaker::finalize()
{

  MsgStream MsgLog(messageService(), name());
  
  MsgLog << MSG::INFO << "Finalizing " << name() << endreq;
  
  MsgLog << MSG::INFO << "Input  Event Number = " << InputEventNumber  << endreq;
  MsgLog << MSG::INFO << "Output Event Number = " << OutputEventNumber << endreq;
  
  this->DeleteBranches();
  
  return StatusCode::SUCCESS;
  
}

StatusCode TriggerTreeMaker::execute()
{

  MsgStream MsgLog(messageService(), name());
  
  InputEventNumber++;
  
  StatusCode DecisionStatus = aStoreGateSvc->retrieve(aTriggerDecisionInfo, TriggerDecisionInfoName);
  
  if(DecisionStatus.isFailure())
  {
    aTriggerDecisionInfo = 0;
    if(InputEventNumber == 1) MsgLog << MSG::INFO << "No Trigger Decision Info" << endreq;
  }
  else 
  {
    if(InputEventNumber == 1) this->SetDecisionBranches();
  }
    
  this->ClearBranches();
  this->FillBranches();
  
  OutputEventNumber++;
  
  return StatusCode::SUCCESS;
  
}

void TriggerTreeMaker::SetBranches()
{
  
}

void TriggerTreeMaker::DeleteBranches()
{
  
}

void TriggerTreeMaker::ClearBranches()
{

  this->ClearDecisionBranches();
  
}

void TriggerTreeMaker::FillBranches()
{

  this->FillDecisionBranches();
  
  aTree->Fill();
  
}

