#include "SingleTopDPDMaker/TruthVertexFilter.h"

TruthVertexFilter::TruthVertexFilter(const std::string& name, ISvcLocator* pSvcLocator) : Algorithm(name, pSvcLocator),
aMcVtxFilterTool(0), aTruthParticleCnvTool(0)
{

  declareProperty("McVtxFilterTool",      aMcVtxFilterTool      = ToolHandle<IMcVtxFilterTool>     ("McVtxFilterTool",      this));
  declareProperty("TruthParticleCnvTool", aTruthParticleCnvTool = ToolHandle<ITruthParticleCnvTool>("TruthParticleCnvTool", this));
        
}

TruthVertexFilter::~TruthVertexFilter(){}

StatusCode TruthVertexFilter::initialize()
{
  
  MsgStream MsgLog(msgSvc(), name());
  
  MsgLog << MSG::INFO << "Initializing " << name() << endreq;
    
  StatusCode status;
  
  status = service("StoreGateSvc", aStoreGateSvc);

  if(status.isFailure()) 
  {
    MsgLog << MSG::FATAL << "StoreGateSvc Unavailable" << endreq;
    return StatusCode::FAILURE;
  }
  
  status = aMcVtxFilterTool.retrieve();
  
  if(status.isFailure()) 
  {
    MsgLog << MSG::FATAL << "McVtxFilterTool Unavailable" << endreq;
    return StatusCode::FAILURE;
  }
    
  status = aTruthParticleCnvTool.retrieve();
  
  if(status.isFailure()) 
  {
    MsgLog << MSG::FATAL << "TruthParticleCnvTool Unavailable" << endreq;
    return StatusCode::FAILURE;
  }
        
  InputEventNumber  = 0;
  OutputEventNumber = 0;
        
  return StatusCode::SUCCESS;
  
}

StatusCode TruthVertexFilter::finalize()
{
  
  MsgStream MsgLog(msgSvc(), name());
  
  MsgLog << MSG::INFO << "Finalizing " << name() << endreq;
  
  MsgLog << MSG::INFO << "Input  Event Number = " << InputEventNumber  << endreq;
  MsgLog << MSG::INFO << "Output Event Number = " << OutputEventNumber << endreq;
  
  aMcVtxFilterTool->stats();
    
  return StatusCode::SUCCESS;
  
}

StatusCode TruthVertexFilter::execute()
{
  
  MsgStream MsgLog(msgSvc(), name());
  
  StatusCode status;
  
  InputEventNumber++;
  
  status = aMcVtxFilterTool->execute();
  
  if(status.isFailure()) 
  {
    MsgLog << MSG::FATAL << "No McVtxFilterTool Execution" << endreq;
    return StatusCode::FAILURE;
  }
  
  status = aTruthParticleCnvTool->execute();
  
  if(status.isFailure()) 
  {
    MsgLog << MSG::FATAL << "No TruthParticleCnvTool Execution" << endreq;
    return StatusCode::FAILURE;
  }
  
  setFilterPassed(true);
  
  OutputEventNumber++;
    
  return StatusCode::SUCCESS;
  
}
